# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.maintenance_configuration_api import MaintenanceConfigurationApi


class TestMaintenanceConfigurationApi(unittest.TestCase):
    """MaintenanceConfigurationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MaintenanceConfigurationApi()

    def tearDown(self) -> None:
        pass

    def test_delete_maintenance_config(self) -> None:
        """Test case for delete_maintenance_config

        Delete maintenance configuration
        """
        pass

    def test_delete_maintenance_config_v2(self) -> None:
        """Test case for delete_maintenance_config_v2

        Delete maintenance configuration
        """
        pass

    def test_get_maintenance_config(self) -> None:
        """Test case for get_maintenance_config

        Maintenance configuration
        """
        pass

    def test_get_maintenance_config_v2(self) -> None:
        """Test case for get_maintenance_config_v2

        Get maintenance configuration
        """
        pass

    def test_get_maintenance_configs(self) -> None:
        """Test case for get_maintenance_configs

        All maintenance configurations
        """
        pass

    def test_get_maintenance_configs_v2(self) -> None:
        """Test case for get_maintenance_configs_v2

        All maintenance configurations
        """
        pass

    def test_pause_recurrent_maintenance_configuration(self) -> None:
        """Test case for pause_recurrent_maintenance_configuration

        Pause maintenance configuration
        """
        pass

    def test_put_maintenance_config(self) -> None:
        """Test case for put_maintenance_config

        Create or update maintenance configuration
        """
        pass

    def test_put_maintenance_config_v2(self) -> None:
        """Test case for put_maintenance_config_v2

        Create or update maintenance configuration
        """
        pass

    def test_resume_recurrent_maintenance_configuration(self) -> None:
        """Test case for resume_recurrent_maintenance_configuration

        Resume maintenance configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()
