# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.infrastructure_resources_api import InfrastructureResourcesApi


class TestInfrastructureResourcesApi(unittest.TestCase):
    """InfrastructureResourcesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = InfrastructureResourcesApi()

    def tearDown(self) -> None:
        pass

    def test_get_monitoring_state(self) -> None:
        """Test case for get_monitoring_state

        Monitored host count
        """
        pass

    def test_get_plugin_payload(self) -> None:
        """Test case for get_plugin_payload

        Get a payload for a snapshot
        """
        pass

    def test_get_snapshot(self) -> None:
        """Test case for get_snapshot

        Get snapshot details
        """
        pass

    def test_get_snapshots(self) -> None:
        """Test case for get_snapshots

        Search snapshots
        """
        pass

    def test_post_snapshots(self) -> None:
        """Test case for post_snapshots

        Get snapshot details for multiple snapshots
        """
        pass

    def test_software_versions(self) -> None:
        """Test case for software_versions

        Get installed software
        """
        pass


if __name__ == '__main__':
    unittest.main()
