# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.synthetic_calls_api import SyntheticCallsApi


class TestSyntheticCallsApi(unittest.TestCase):
    """SyntheticCallsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SyntheticCallsApi()

    def tearDown(self) -> None:
        pass

    def test_delete_synthetic_call(self) -> None:
        """Test case for delete_synthetic_call

        Delete synthetic call configurations
        """
        pass

    def test_get_synthetic_calls(self) -> None:
        """Test case for get_synthetic_calls

        Synthetic call configurations
        """
        pass

    def test_update_synthetic_call(self) -> None:
        """Test case for update_synthetic_call

        Update synthetic call configurations
        """
        pass


if __name__ == '__main__':
    unittest.main()
