# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.business_monitoring_api import BusinessMonitoringApi


class TestBusinessMonitoringApi(unittest.TestCase):
    """BusinessMonitoringApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BusinessMonitoringApi()

    def tearDown(self) -> None:
        pass

    def test_create_business_perspective(self) -> None:
        """Test case for create_business_perspective

        Create business perspective
        """
        pass

    def test_delete_business_perspective(self) -> None:
        """Test case for delete_business_perspective

        Delete business perspective
        """
        pass

    def test_get_activities(self) -> None:
        """Test case for get_activities

        Get Business Activities
        """
        pass

    def test_get_activities_csv(self) -> None:
        """Test case for get_activities_csv

        Download Business Activities
        """
        pass

    def test_get_business_perspective(self) -> None:
        """Test case for get_business_perspective

        Get business perspective
        """
        pass

    def test_get_business_perspectives(self) -> None:
        """Test case for get_business_perspectives

        Get all business perspectives
        """
        pass

    def test_get_business_tag_catalog(self) -> None:
        """Test case for get_business_tag_catalog

        Get business tag catalog
        """
        pass

    def test_update_business_perspective(self) -> None:
        """Test case for update_business_perspective

        Update business perspective
        """
        pass


if __name__ == '__main__':
    unittest.main()
