# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.application_config import ApplicationConfig

class TestApplicationConfig(unittest.TestCase):
    """ApplicationConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApplicationConfig:
        """Test ApplicationConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApplicationConfig`
        """
        model = ApplicationConfig()
        if include_optional:
            return ApplicationConfig(
                access_rules = [
                    instana_client.models.access_rule.AccessRule(
                        access_type = 'READ', 
                        related_id = '', 
                        relation_type = 'USER', )
                    ],
                boundary_scope = 'ALL',
                id = '0',
                label = '0',
                match_specification = instana_client.models.match_expression_dto.MatchExpressionDTO(
                    type = '', ),
                scope = 'INCLUDE_NO_DOWNSTREAM',
                tag_filter_expression = instana_client.models.tag_filter_expression_element.TagFilterExpressionElement(
                    type = '', )
            )
        else:
            return ApplicationConfig(
                access_rules = [
                    instana_client.models.access_rule.AccessRule(
                        access_type = 'READ', 
                        related_id = '', 
                        relation_type = 'USER', )
                    ],
                boundary_scope = 'ALL',
                id = '0',
                label = '0',
                scope = 'INCLUDE_NO_DOWNSTREAM',
        )
        """

    def testApplicationConfig(self):
        """Test ApplicationConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
