# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.simple_metric_configuration import SimpleMetricConfiguration

class TestSimpleMetricConfiguration(unittest.TestCase):
    """SimpleMetricConfiguration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SimpleMetricConfiguration:
        """Test SimpleMetricConfiguration
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SimpleMetricConfiguration`
        """
        model = SimpleMetricConfiguration()
        if include_optional:
            return SimpleMetricConfiguration(
                aggregation = 'SUM',
                cross_series_aggregation = 'SUM',
                granularity = 56,
                metric = '',
                regex = True,
                required = True,
                operation = instana_client.models.arithmetic_operation.ArithmeticOperation(
                    left = instana_client.models.arithmetic_operand.ArithmeticOperand(), 
                    operator = '', 
                    right = instana_client.models.arithmetic_operand.ArithmeticOperand(), )
            )
        else:
            return SimpleMetricConfiguration(
                aggregation = 'SUM',
                metric = '',
        )
        """

    def testSimpleMetricConfiguration(self):
        """Test SimpleMetricConfiguration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
