# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.test_result import TestResult

class TestTestResult(unittest.TestCase):
    """TestResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TestResult:
        """Test TestResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TestResult`
        """
        model = TestResult()
        if include_optional:
            return TestResult(
                test_result = [
                    instana_client.models.test_result_item.TestResultItem(
                        application_id = '', 
                        application_ids = [
                            ''
                            ], 
                        custom_tags = {
                            'key' : ''
                            }, 
                        location_id = [
                            ''
                            ], 
                        metrics = [
                            {
                                'key' : None
                                }
                            ], 
                        mobile_application_ids = [
                            ''
                            ], 
                        service_id = '', 
                        test_id = '', 
                        test_name = '', 
                        website_ids = [
                            ''
                            ], )
                    ],
                test_result_items = [
                    instana_client.models.test_result_item.TestResultItem(
                        application_id = '', 
                        application_ids = [
                            ''
                            ], 
                        custom_tags = {
                            'key' : ''
                            }, 
                        location_id = [
                            ''
                            ], 
                        metrics = [
                            {
                                'key' : None
                                }
                            ], 
                        mobile_application_ids = [
                            ''
                            ], 
                        service_id = '', 
                        test_id = '', 
                        test_name = '', 
                        website_ids = [
                            ''
                            ], )
                    ]
            )
        else:
            return TestResult(
        )
        """

    def testTestResult(self):
        """Test TestResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
