# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.application_analyze_api import ApplicationAnalyzeApi


class TestApplicationAnalyzeApi(unittest.TestCase):
    """ApplicationAnalyzeApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationAnalyzeApi()

    def tearDown(self) -> None:
        pass

    def test_get_call_details(self) -> None:
        """Test case for get_call_details

        Get call detail
        """
        pass

    def test_get_call_group(self) -> None:
        """Test case for get_call_group

        Get grouped call metrics
        """
        pass

    def test_get_correlated_traces(self) -> None:
        """Test case for get_correlated_traces

        Resolve Trace IDs from Monitoring Beacons.
        """
        pass

    def test_get_trace_download(self) -> None:
        """Test case for get_trace_download

        Get trace detail
        """
        pass

    def test_get_trace_groups(self) -> None:
        """Test case for get_trace_groups

        Get grouped trace metrics
        """
        pass

    def test_get_traces(self) -> None:
        """Test case for get_traces

        Get all traces
        """
        pass


if __name__ == '__main__':
    unittest.main()
