# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.apdex_settings_api import ApdexSettingsApi


class TestApdexSettingsApi(unittest.TestCase):
    """ApdexSettingsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApdexSettingsApi()

    def tearDown(self) -> None:
        pass

    def test_create_apdex_configuration(self) -> None:
        """Test case for create_apdex_configuration

        Create Apdex Configuration
        """
        pass

    def test_delete_apdex_configuration(self) -> None:
        """Test case for delete_apdex_configuration

        Delete Apdex Configuration
        """
        pass

    def test_get_all_apdex_configurations(self) -> None:
        """Test case for get_all_apdex_configurations

        Get All Apdex Configurations
        """
        pass

    def test_get_apdex_configuration(self) -> None:
        """Test case for get_apdex_configuration

        Get Apdex Configuration
        """
        pass

    def test_get_apdex_configurations_for_entity_type_and_id(self) -> None:
        """Test case for get_apdex_configurations_for_entity_type_and_id

        Get all Apdex configurations for entity type and entity id
        """
        pass


if __name__ == '__main__':
    unittest.main()
