# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.teams_api import TeamsApi


class TestTeamsApi(unittest.TestCase):
    """TeamsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TeamsApi()

    def tearDown(self) -> None:
        pass

    def test_create_team(self) -> None:
        """Test case for create_team

        Create team
        """
        pass

    def test_delete_team(self) -> None:
        """Test case for delete_team

        Delete team
        """
        pass

    def test_get_team(self) -> None:
        """Test case for get_team

        Get team by ID
        """
        pass

    def test_get_teams(self) -> None:
        """Test case for get_teams

        Get all teams
        """
        pass

    def test_update_team(self) -> None:
        """Test case for update_team

        Update team
        """
        pass


if __name__ == '__main__':
    unittest.main()
