# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.get_dynamic_parameter_values import GetDynamicParameterValues

class TestGetDynamicParameterValues(unittest.TestCase):
    """GetDynamicParameterValues unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetDynamicParameterValues:
        """Test GetDynamicParameterValues
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetDynamicParameterValues`
        """
        model = GetDynamicParameterValues()
        if include_optional:
            return GetDynamicParameterValues(
                event_id = '',
                parameters = [
                    instana_client.models.dynamic_parameter.DynamicParameter(
                        key = '', 
                        name = '', 
                        resolved_value = '', 
                        tag_name = '', )
                    ],
                timestamp = 56
            )
        else:
            return GetDynamicParameterValues(
                event_id = '',
                parameters = [
                    instana_client.models.dynamic_parameter.DynamicParameter(
                        key = '', 
                        name = '', 
                        resolved_value = '', 
                        tag_name = '', )
                    ],
                timestamp = 56,
        )
        """

    def testGetDynamicParameterValues(self):
        """Test GetDynamicParameterValues"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
