# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from instana_client.models.policy_scheduling import PolicyScheduling
from typing import Optional, Set
from typing_extensions import Self

class Trigger(BaseModel):
    """
    The trigger is the Instana event or Smart Alert that defines the initial conditions that must be met for the policy to apply on the actions in `typeConfiguration`.
    """ # noqa: E501
    description: Optional[StrictStr] = Field(default=None, description="A description for the trigger.")
    id: Optional[StrictStr] = Field(default=None, description="Trigger (Instana event or Smart Alert) identifier.")
    name: Optional[StrictStr] = Field(default=None, description="A name of the trigger (name of Instana event or Smart Alert).")
    scheduling: Optional[PolicyScheduling] = None
    type: StrictStr = Field(description="Instana event type, Smart Alert type, or 'schedule'. The type must be one of the enum values.")
    __properties: ClassVar[List[str]] = ["description", "id", "name", "scheduling", "type"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['customEvent', 'builtinEvent', 'applicationSmartAlert', 'globalApplicationSmartAlert', 'websiteSmartAlert', 'infraSmartAlert', 'mobileAppSmartAlert', 'syntheticsSmartAlert', 'logSmartAlert', 'sloSmartAlert', 'schedule']):
            raise ValueError("must be one of enum values ('customEvent', 'builtinEvent', 'applicationSmartAlert', 'globalApplicationSmartAlert', 'websiteSmartAlert', 'infraSmartAlert', 'mobileAppSmartAlert', 'syntheticsSmartAlert', 'logSmartAlert', 'sloSmartAlert', 'schedule')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Trigger from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of scheduling
        if self.scheduling:
            _dict['scheduling'] = self.scheduling.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Trigger from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "description": obj.get("description"),
            "id": obj.get("id"),
            "name": obj.get("name"),
            "scheduling": PolicyScheduling.from_dict(obj["scheduling"]) if obj.get("scheduling") is not None else None,
            "type": obj.get("type")
        })
        return _obj


