# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.kubernetes_physical_context import KubernetesPhysicalContext

class TestKubernetesPhysicalContext(unittest.TestCase):
    """KubernetesPhysicalContext unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KubernetesPhysicalContext:
        """Test KubernetesPhysicalContext
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KubernetesPhysicalContext`
        """
        model = KubernetesPhysicalContext()
        if include_optional:
            return KubernetesPhysicalContext(
                cluster = instana_client.models.snapshot_preview.SnapshotPreview(
                    data = {
                        'key' : None
                        }, 
                    id = '', 
                    label = '', 
                    plugin = '', 
                    time = 1, ),
                namespace = instana_client.models.snapshot_preview.SnapshotPreview(
                    data = {
                        'key' : None
                        }, 
                    id = '', 
                    label = '', 
                    plugin = '', 
                    time = 1, ),
                node = instana_client.models.snapshot_preview.SnapshotPreview(
                    data = {
                        'key' : None
                        }, 
                    id = '', 
                    label = '', 
                    plugin = '', 
                    time = 1, ),
                pod = instana_client.models.snapshot_preview.SnapshotPreview(
                    data = {
                        'key' : None
                        }, 
                    id = '', 
                    label = '', 
                    plugin = '', 
                    time = 1, )
            )
        else:
            return KubernetesPhysicalContext(
        )
        """

    def testKubernetesPhysicalContext(self):
        """Test KubernetesPhysicalContext"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
