# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.event_result import EventResult

class TestEventResult(unittest.TestCase):
    """EventResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> EventResult:
        """Test EventResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EventResult`
        """
        model = EventResult()
        if include_optional:
            return EventResult(
                detail = '',
                end = 56,
                entity_label = '',
                entity_name = '',
                entity_type = '',
                event_id = '',
                event_specification_id = '',
                fix_suggestion = '',
                metrics = [
                    {
                        'key' : None
                        }
                    ],
                probable_cause = {
                    'key' : None
                    },
                problem = '',
                recent_events = [
                    {
                        'key' : None
                        }
                    ],
                severity = 56,
                snapshot_id = '',
                start = 56,
                state = '',
                type = ''
            )
        else:
            return EventResult(
        )
        """

    def testEventResult(self):
        """Test EventResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
