# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.api_team_scope import ApiTeamScope

class TestApiTeamScope(unittest.TestCase):
    """ApiTeamScope unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiTeamScope:
        """Test ApiTeamScope
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiTeamScope`
        """
        model = ApiTeamScope()
        if include_optional:
            return ApiTeamScope(
                access_permissions = [
                    'LIMITED_APPLICATIONS_SCOPE'
                    ],
                action_filter = '',
                applications = [
                    ''
                    ],
                business_perspectives = [
                    ''
                    ],
                infra_dfq_filter = '',
                kubernetes_clusters = [
                    ''
                    ],
                kubernetes_namespaces = [
                    ''
                    ],
                log_filter = '',
                mobile_apps = [
                    ''
                    ],
                restricted_application_filter = instana_client.models.api_restricted_application_filter.ApiRestrictedApplicationFilter(
                    label = '', 
                    restricting_application_id = '', 
                    scope = 'INCLUDE_NO_DOWNSTREAM', 
                    tag_filter_expression = instana_client.models.tag_filter_expression_element.TagFilterExpressionElement(
                        type = '', ), ),
                slo_ids = [
                    ''
                    ],
                synthetic_credentials = [
                    ''
                    ],
                synthetic_tests = [
                    ''
                    ],
                tag_ids = [
                    ''
                    ],
                websites = [
                    ''
                    ]
            )
        else:
            return ApiTeamScope(
        )
        """

    def testApiTeamScope(self):
        """Test ApiTeamScope"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
