# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from instana_client.models.service_levels_static_threshold_config import ServiceLevelsStaticThresholdConfig
from typing import Optional, Set
from typing_extensions import Self

class ServiceLevelsBurnRateConfig(BaseModel):
    """
    This is the burn rate alert configuration which defines alerting windows and corresponding thresholds. This configuration must to specified for BURN_RATE_V2 Alerts.
    """ # noqa: E501
    alert_window_type: Optional[StrictStr] = Field(default=None, description="Specifies the Burn Rate Alerting Window type: SINGLE for single window/threshold alerts, or LONG and SHORT for multi-window/threshold alerts.", alias="alertWindowType")
    duration: StrictInt = Field(description="Duration of the Burn Rate Alerting Window.")
    duration_unit_type: StrictStr = Field(description="Duration Unit Type of the Burn Rate Alerting Window.", alias="durationUnitType")
    threshold: ServiceLevelsStaticThresholdConfig
    __properties: ClassVar[List[str]] = ["alertWindowType", "duration", "durationUnitType", "threshold"]

    @field_validator('alert_window_type')
    def alert_window_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['SINGLE', 'LONG', 'SHORT']):
            raise ValueError("must be one of enum values ('SINGLE', 'LONG', 'SHORT')")
        return value

    @field_validator('duration_unit_type')
    def duration_unit_type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['millisecond', 'second', 'minute', 'hour', 'day', 'week', 'month']):
            raise ValueError("must be one of enum values ('millisecond', 'second', 'minute', 'hour', 'day', 'week', 'month')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServiceLevelsBurnRateConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of threshold
        if self.threshold:
            _dict['threshold'] = self.threshold.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServiceLevelsBurnRateConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "alertWindowType": obj.get("alertWindowType"),
            "duration": obj.get("duration"),
            "durationUnitType": obj.get("durationUnitType"),
            "threshold": ServiceLevelsStaticThresholdConfig.from_dict(obj["threshold"]) if obj.get("threshold") is not None else None
        })
        return _obj


