# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.validated_maintenance_config_v2_with_state_and_occurrence import ValidatedMaintenanceConfigV2WithStateAndOccurrence

class TestValidatedMaintenanceConfigV2WithStateAndOccurrence(unittest.TestCase):
    """ValidatedMaintenanceConfigV2WithStateAndOccurrence unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ValidatedMaintenanceConfigV2WithStateAndOccurrence:
        """Test ValidatedMaintenanceConfigV2WithStateAndOccurrence
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ValidatedMaintenanceConfigV2WithStateAndOccurrence`
        """
        model = ValidatedMaintenanceConfigV2WithStateAndOccurrence()
        if include_optional:
            return ValidatedMaintenanceConfigV2WithStateAndOccurrence(
                application_names = [
                    ''
                    ],
                id = '',
                invalid = True,
                last_updated = 1,
                name = '',
                occurrence = instana_client.models.occurrence.Occurrence(
                    end = 1, 
                    start = 0, ),
                paused = True,
                query = '',
                retrigger_open_alerts_enabled = True,
                scheduling = instana_client.models.maintenance_config_scheduling.MaintenanceConfigScheduling(
                    duration = instana_client.models.duration.Duration(
                        amount = 1, 
                        unit = 'MINUTES', ), 
                    start = 1, 
                    type = '', ),
                state = 'UNSCHEDULED',
                tag_filter_expression = instana_client.models.tag_filter_expression_element.TagFilterExpressionElement(
                    type = '', ),
                tag_filter_expression_enabled = True
            )
        else:
            return ValidatedMaintenanceConfigV2WithStateAndOccurrence(
                id = '',
                name = '',
                occurrence = instana_client.models.occurrence.Occurrence(
                    end = 1, 
                    start = 0, ),
                query = '',
                scheduling = instana_client.models.maintenance_config_scheduling.MaintenanceConfigScheduling(
                    duration = instana_client.models.duration.Duration(
                        amount = 1, 
                        unit = 'MINUTES', ), 
                    start = 1, 
                    type = '', ),
        )
        """

    def testValidatedMaintenanceConfigV2WithStateAndOccurrence(self):
        """Test ValidatedMaintenanceConfigV2WithStateAndOccurrence"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
