# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.synthetic_resource_update_list_dns_filter_target_value_list_dns_filter_target_value import SyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue

class TestSyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue(unittest.TestCase):
    """SyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue:
        """Test SyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue`
        """
        model = SyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue()
        if include_optional:
            return SyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue(
                add = [
                    instana_client.models.dns_filter_target_value.DNSFilterTargetValue(
                        key = 'ALL', 
                        operator = 'CONTAINS', 
                        value = '', )
                    ],
                remove = [
                    instana_client.models.dns_filter_target_value.DNSFilterTargetValue(
                        key = 'ALL', 
                        operator = 'CONTAINS', 
                        value = '', )
                    ]
            )
        else:
            return SyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue(
        )
        """

    def testSyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue(self):
        """Test SyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
