# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.releases_api import ReleasesApi


class TestReleasesApi(unittest.TestCase):
    """ReleasesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ReleasesApi()

    def tearDown(self) -> None:
        pass

    def test_delete_release(self) -> None:
        """Test case for delete_release

        Delete release
        """
        pass

    def test_get_all_releases(self) -> None:
        """Test case for get_all_releases

        Get all releases
        """
        pass

    def test_get_release(self) -> None:
        """Test case for get_release

        Get release
        """
        pass

    def test_post_release(self) -> None:
        """Test case for post_release

        Create release
        """
        pass

    def test_put_release(self) -> None:
        """Test case for put_release

        Update release
        """
        pass


if __name__ == '__main__':
    unittest.main()
