# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.infrastructure_topology_api import InfrastructureTopologyApi


class TestInfrastructureTopologyApi(unittest.TestCase):
    """InfrastructureTopologyApi unit test stubs"""

    def setUp(self) -> None:
        self.api = InfrastructureTopologyApi()

    def tearDown(self) -> None:
        pass

    def test_get_related_hosts(self) -> None:
        """Test case for get_related_hosts

        Related hosts
        """
        pass

    def test_get_topology(self) -> None:
        """Test case for get_topology

        Gets the infrastructure topology
        """
        pass


if __name__ == '__main__':
    unittest.main()
