# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.mobile_app_configuration_api import MobileAppConfigurationApi


class TestMobileAppConfigurationApi(unittest.TestCase):
    """MobileAppConfigurationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MobileAppConfigurationApi()

    def tearDown(self) -> None:
        pass

    def test_clear_mobile_app_source_map_upload_configuration(self) -> None:
        """Test case for clear_mobile_app_source_map_upload_configuration

        Clear sourcemap files for sourcemap upload configuration
        """
        pass

    def test_commit_mobile_app_source_map_file(self) -> None:
        """Test case for commit_mobile_app_source_map_file

        Commit sourcemap file upload for mobile app
        """
        pass

    def test_delete_mobile_app_config(self) -> None:
        """Test case for delete_mobile_app_config

        Remove mobile app
        """
        pass

    def test_delete_mobile_app_source_map_upload_configuration(self) -> None:
        """Test case for delete_mobile_app_source_map_upload_configuration

        Delete sourcemap configuration for mobile app
        """
        pass

    def test_get_mobile_app_config(self) -> None:
        """Test case for get_mobile_app_config

        Get configured mobile apps
        """
        pass

    def test_get_mobile_app_geo_location_configuration(self) -> None:
        """Test case for get_mobile_app_geo_location_configuration

        Get geo location configuration for mobile app
        """
        pass

    def test_get_mobile_app_geo_mapping_rules(self) -> None:
        """Test case for get_mobile_app_geo_mapping_rules

        Get custom geo mapping rules for mobile app
        """
        pass

    def test_get_mobile_app_ip_masking_configuration(self) -> None:
        """Test case for get_mobile_app_ip_masking_configuration

        Get IP masking configuration for mobile app
        """
        pass

    def test_get_mobile_app_source_map_file(self) -> None:
        """Test case for get_mobile_app_source_map_file

        Get sourcemap configuration for mobile app
        """
        pass

    def test_get_mobile_app_source_map_files(self) -> None:
        """Test case for get_mobile_app_source_map_files

        Get all sourcemap configurations for mobile app
        """
        pass

    def test_get_single_mobile_app_config(self) -> None:
        """Test case for get_single_mobile_app_config

        Get mobile app configuration by ID
        """
        pass

    def test_post_mobile_app_config(self) -> None:
        """Test case for post_mobile_app_config

        Configure new mobile app
        """
        pass

    def test_post_mobile_app_source_map_config(self) -> None:
        """Test case for post_mobile_app_source_map_config

        Add new sourcemap configuration for mobile app
        """
        pass

    def test_rename_mobile_app_config(self) -> None:
        """Test case for rename_mobile_app_config

        Rename mobile app
        """
        pass

    def test_set_mobile_app_geo_mapping_rules(self) -> None:
        """Test case for set_mobile_app_geo_mapping_rules

        Set custom geo mapping rules for mobile app
        """
        pass

    def test_update_mobile_app_geo_location_configuration(self) -> None:
        """Test case for update_mobile_app_geo_location_configuration

        Update geo location configuration for mobile app
        """
        pass

    def test_update_mobile_app_ip_masking_configuration(self) -> None:
        """Test case for update_mobile_app_ip_masking_configuration

        Update IP masking configuration for mobile app
        """
        pass

    def test_update_mobile_app_teams(self) -> None:
        """Test case for update_mobile_app_teams

        Update teams assigned to the mobile app
        """
        pass

    def test_upload_mobile_app_source_map_file(self) -> None:
        """Test case for upload_mobile_app_source_map_file

        Upload sourcemap file for mobile app
        """
        pass


if __name__ == '__main__':
    unittest.main()
