# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.snapshot_result import SnapshotResult

class TestSnapshotResult(unittest.TestCase):
    """SnapshotResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SnapshotResult:
        """Test SnapshotResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SnapshotResult`
        """
        model = SnapshotResult()
        if include_optional:
            return SnapshotResult(
                items = [
                    instana_client.models.snapshot_item.SnapshotItem(
                        data = {
                            'key' : None
                            }, 
                        from = 56, 
                        host = '', 
                        label = '', 
                        plugin = 'host', 
                        snapshot_id = '', 
                        tags = [
                            ''
                            ], 
                        to = 56, )
                    ]
            )
        else:
            return SnapshotResult(
        )
        """

    def testSnapshotResult(self):
        """Test SnapshotResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
