# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.synthetic_test import SyntheticTest

class TestSyntheticTest(unittest.TestCase):
    """SyntheticTest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyntheticTest:
        """Test SyntheticTest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyntheticTest`
        """
        model = SyntheticTest()
        if include_optional:
            return SyntheticTest(
                active = True,
                application_id = '',
                application_label = '',
                application_labels = [
                    ''
                    ],
                applications = [
                    ''
                    ],
                configuration = instana_client.models.synthetic_type_configuration.SyntheticTypeConfiguration(
                    mark_synthetic_call = True, 
                    retries = 0, 
                    retry_interval = 1, 
                    synthetic_type = 'BrowserScript', 
                    timeout = '', ),
                created_at = 56,
                created_by = '',
                custom_properties = {
                    'key' : ''
                    },
                description = '',
                id = '0',
                label = '0',
                location_display_labels = [
                    ''
                    ],
                location_labels = [
                    ''
                    ],
                locations = [
                    ''
                    ],
                mobile_app_labels = [
                    ''
                    ],
                mobile_apps = [
                    ''
                    ],
                modified_at = 56,
                modified_by = '',
                playback_mode = 'Simultaneous',
                rbac_tags = [
                    instana_client.models.api_tag.ApiTag(
                        display_name = '', 
                        id = '', )
                    ],
                tenant_id = '',
                test_frequency = 1,
                website_labels = [
                    ''
                    ],
                websites = [
                    ''
                    ]
            )
        else:
            return SyntheticTest(
                active = True,
                configuration = instana_client.models.synthetic_type_configuration.SyntheticTypeConfiguration(
                    mark_synthetic_call = True, 
                    retries = 0, 
                    retry_interval = 1, 
                    synthetic_type = 'BrowserScript', 
                    timeout = '', ),
                label = '0',
                locations = [
                    ''
                    ],
                test_frequency = 1,
        )
        """

    def testSyntheticTest(self):
        """Test SyntheticTest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
