# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.synthetic_datacenter import SyntheticDatacenter

class TestSyntheticDatacenter(unittest.TestCase):
    """SyntheticDatacenter unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyntheticDatacenter:
        """Test SyntheticDatacenter
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyntheticDatacenter`
        """
        model = SyntheticDatacenter()
        if include_optional:
            return SyntheticDatacenter(
                city_name = '',
                code = '0',
                configuration = instana_client.models.synthetic_datacenter_configuration.SyntheticDatacenterConfiguration(
                    ip_addresses = [
                        ''
                        ], ),
                country_name = '',
                datacenter_id = '',
                expected_active_at = 56,
                label = '0',
                latitude = 1.337,
                location_label = '',
                longitude = 1.337,
                modified_at = 56,
                provider = '0',
                status = ''
            )
        else:
            return SyntheticDatacenter(
                city_name = '',
                code = '0',
                country_name = '',
                label = '0',
                provider = '0',
        )
        """

    def testSyntheticDatacenter(self):
        """Test SyntheticDatacenter"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
