# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.synthetic_test_update import SyntheticTestUpdate

class TestSyntheticTestUpdate(unittest.TestCase):
    """SyntheticTestUpdate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyntheticTestUpdate:
        """Test SyntheticTestUpdate
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyntheticTestUpdate`
        """
        model = SyntheticTestUpdate()
        if include_optional:
            return SyntheticTestUpdate(
                active = True,
                applications = instana_client.models.synthetic_resource_update_list_string_list_string.SyntheticResourceUpdateListStringListString(
                    add = [
                        ''
                        ], 
                    remove = [
                        ''
                        ], ),
                custom_properties = instana_client.models.synthetic_resource_update_map_string_string_list_string.SyntheticResourceUpdateMapStringStringListString(
                    add = {
                        'key' : ''
                        }, 
                    remove = [
                        ''
                        ], ),
                ids = [
                    ''
                    ],
                last_modified_at = [
                    56
                    ],
                locations = instana_client.models.synthetic_resource_update_list_string_list_string.SyntheticResourceUpdateListStringListString(
                    add = [
                        ''
                        ], 
                    remove = [
                        ''
                        ], ),
                mobile_apps = instana_client.models.synthetic_resource_update_list_string_list_string.SyntheticResourceUpdateListStringListString(
                    add = [
                        ''
                        ], 
                    remove = [
                        ''
                        ], ),
                modified_by = '',
                shallow_update = True,
                synthetic_update_type = 'Deep',
                test_frequency = 1,
                websites = instana_client.models.synthetic_resource_update_list_string_list_string.SyntheticResourceUpdateListStringListString(
                    add = [
                        ''
                        ], 
                    remove = [
                        ''
                        ], )
            )
        else:
            return SyntheticTestUpdate(
                synthetic_update_type = 'Deep',
        )
        """

    def testSyntheticTestUpdate(self):
        """Test SyntheticTestUpdate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
