# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.synthetic_resource_update_list_ssl_certificate_validation_list_ssl_certificate_validation import SyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation

class TestSyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation(unittest.TestCase):
    """SyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation:
        """Test SyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation`
        """
        model = SyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation()
        if include_optional:
            return SyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation(
                add = [
                    instana_client.models.ssl_certificate_validation.SSLCertificateValidation(
                        key = '', 
                        operator = 'CONTAINS', 
                        value = instana_client.models.value.value(), )
                    ],
                remove = [
                    instana_client.models.ssl_certificate_validation.SSLCertificateValidation(
                        key = '', 
                        operator = 'CONTAINS', 
                        value = instana_client.models.value.value(), )
                    ]
            )
        else:
            return SyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation(
        )
        """

    def testSyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation(self):
        """Test SyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
