# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.mobile_app_monitoring_beacon import MobileAppMonitoringBeacon

class TestMobileAppMonitoringBeacon(unittest.TestCase):
    """MobileAppMonitoringBeacon unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MobileAppMonitoringBeacon:
        """Test MobileAppMonitoringBeacon
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MobileAppMonitoringBeacon`
        """
        model = MobileAppMonitoringBeacon()
        if include_optional:
            return MobileAppMonitoringBeacon(
                accuracy_radius = -1,
                agent_version = '',
                app_build = '',
                app_version = '',
                app_version_number = -1,
                available_mb = -1,
                backend_trace_id = '',
                batch_size = 1,
                beacon_id = '',
                bundle_identifier = '',
                bytes_ingested = 56,
                carrier = '',
                city = '',
                clock_skew = 0,
                cold_start_time_ms = -1,
                connection_type = '',
                continent = '',
                continent_code = '',
                country = '',
                country_code = '',
                current_app_state = '',
                custom_event_name = '',
                custom_metric = 1.337,
                decoded_body_size = -1,
                device_hardware = '',
                device_manufacturer = '',
                device_model = '',
                drop_view = '',
                duration = 0,
                effective_connection_type = '',
                encoded_body_size = -1,
                environment = '',
                error_count = 0,
                error_id = '',
                error_message = '',
                error_type = '',
                google_play_services_missing = True,
                hot_start_time_ms = -1,
                http_call_headers = {
                    'key' : ''
                    },
                http_call_method = '',
                http_call_origin = '',
                http_call_path = '',
                http_call_status = -1,
                http_call_url = '',
                ingestion_time = 1,
                internal_meta = {
                    'key' : ''
                    },
                label = '',
                latitude = 1.337,
                longitude = 1.337,
                max_mb = -1,
                meta = {
                    'key' : ''
                    },
                mobile_app_id = '',
                mobile_app_label = '',
                os_name = '',
                os_version = '',
                parent_beacon_id = '',
                parsed_stack_trace = '',
                performance_subtype = '',
                platform = '',
                rate_limit_beacon_type = '',
                rate_limit_count = 0,
                rate_limit_custom_metric_val = [
                    1.337
                    ],
                rate_limit_time_max = 0,
                rate_limit_time_min = 0,
                region = '',
                rooted = True,
                session_id = '',
                stack_trace = '',
                stack_trace_key_checksum = '',
                stack_trace_key_information = '',
                stack_trace_line = [
                    instana_client.models.stack_trace_line.StackTraceLine(
                        column = -1, 
                        file = '', 
                        line = -1, 
                        name = '', 
                        translation_explanation = '', 
                        translation_status = -1, )
                    ],
                stack_trace_parsing_status = -1,
                subdivision = '',
                subdivision_code = '',
                tenant = '',
                timestamp = 1,
                transfer_size = -1,
                type = '',
                unit = '',
                use_features = [
                    ''
                    ],
                used_mb = -1,
                user_email = '',
                user_id = '',
                user_ip = '',
                user_languages = [
                    ''
                    ],
                user_name = '',
                user_session_id = '',
                view = '',
                viewport_height = -1,
                viewport_width = -1,
                warm_start_time_ms = -1
            )
        else:
            return MobileAppMonitoringBeacon(
                beacon_id = '',
                mobile_app_id = '',
                performance_subtype = '',
                rate_limit_beacon_type = '',
                type = '',
        )
        """

    def testMobileAppMonitoringBeacon(self):
        """Test MobileAppMonitoringBeacon"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
