# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.log_volume_usage_result import LogVolumeUsageResult

class TestLogVolumeUsageResult(unittest.TestCase):
    """LogVolumeUsageResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LogVolumeUsageResult:
        """Test LogVolumeUsageResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LogVolumeUsageResult`
        """
        model = LogVolumeUsageResult()
        if include_optional:
            return LogVolumeUsageResult(
                log_volume_usage_items = [
                    instana_client.models.log_volume_usage_item.LogVolumeUsageItem(
                        log_volume = 56, 
                        number_of_month = 1, 
                        retention_periods = [
                            instana_client.models.retention_period.RetentionPeriod(
                                log_volume = 56, 
                                log_volume_groups = [
                                    instana_client.models.log_volume_group.LogVolumeGroup(
                                        label = '', 
                                        log_volume = 56, )
                                    ], 
                                retention_days = 7, )
                            ], )
                    ]
            )
        else:
            return LogVolumeUsageResult(
                log_volume_usage_items = [
                    instana_client.models.log_volume_usage_item.LogVolumeUsageItem(
                        log_volume = 56, 
                        number_of_month = 1, 
                        retention_periods = [
                            instana_client.models.retention_period.RetentionPeriod(
                                log_volume = 56, 
                                log_volume_groups = [
                                    instana_client.models.log_volume_group.LogVolumeGroup(
                                        label = '', 
                                        log_volume = 56, )
                                    ], 
                                retention_days = 7, )
                            ], )
                    ],
        )
        """

    def testLogVolumeUsageResult(self):
        """Test LogVolumeUsageResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
