# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.authentication_api import AuthenticationApi


class TestAuthenticationApi(unittest.TestCase):
    """AuthenticationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AuthenticationApi()

    def tearDown(self) -> None:
        pass

    def test_delete_google_sso_config(self) -> None:
        """Test case for delete_google_sso_config

        Delete Google SSO configuration
        """
        pass

    def test_delete_ldap_config(self) -> None:
        """Test case for delete_ldap_config

        Delete LDAP configuration
        """
        pass

    def test_delete_oidc_config(self) -> None:
        """Test case for delete_oidc_config

        Delete OIDC configuration
        """
        pass

    def test_delete_saml_config(self) -> None:
        """Test case for delete_saml_config

        Delete SAML configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()
