# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.trace_groups_result import TraceGroupsResult

class TestTraceGroupsResult(unittest.TestCase):
    """TraceGroupsResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TraceGroupsResult:
        """Test TraceGroupsResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TraceGroupsResult`
        """
        model = TraceGroupsResult()
        if include_optional:
            return TraceGroupsResult(
                adjusted_timeframe = instana_client.models.adjusted_timeframe.AdjustedTimeframe(
                    to = 56, 
                    window_size = 0, ),
                can_load_more = True,
                items = [
                    instana_client.models.trace_groups_item.TraceGroupsItem(
                        cursor = instana_client.models.cursor.cursor(), 
                        metrics = {
                            'key' : [
                                [
                                    1.337
                                    ]
                                ]
                            }, 
                        name = '', 
                        timestamp = 0, )
                    ],
                total_hits = 0,
                total_represented_item_count = 0,
                total_retained_item_count = 0
            )
        else:
            return TraceGroupsResult(
                items = [
                    instana_client.models.trace_groups_item.TraceGroupsItem(
                        cursor = instana_client.models.cursor.cursor(), 
                        metrics = {
                            'key' : [
                                [
                                    1.337
                                    ]
                                ]
                            }, 
                        name = '', 
                        timestamp = 0, )
                    ],
        )
        """

    def testTraceGroupsResult(self):
        """Test TraceGroupsResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
