# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.synthetic_bulk_response import SyntheticBulkResponse

class TestSyntheticBulkResponse(unittest.TestCase):
    """SyntheticBulkResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyntheticBulkResponse:
        """Test SyntheticBulkResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyntheticBulkResponse`
        """
        model = SyntheticBulkResponse()
        if include_optional:
            return SyntheticBulkResponse(
                error_message = '',
                id = '',
                status = ''
            )
        else:
            return SyntheticBulkResponse(
        )
        """

    def testSyntheticBulkResponse(self):
        """Test SyntheticBulkResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
