# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.action_history_api import ActionHistoryApi


class TestActionHistoryApi(unittest.TestCase):
    """ActionHistoryApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ActionHistoryApi()

    def tearDown(self) -> None:
        pass

    def test_add_action_instance(self) -> None:
        """Test case for add_action_instance

        Run an automation action.
        """
        pass

    def test_delete_action_instance(self) -> None:
        """Test case for delete_action_instance

        Deletes an automation action run result from the action run history by ID.
        """
        pass

    def test_delete_action_instances(self) -> None:
        """Test case for delete_action_instances

        Delete automation action run results.
        """
        pass

    def test_get_action_instance(self) -> None:
        """Test case for get_action_instance

        Get the details of an automation action run result by ID from action run history.
        """
        pass

    def test_get_action_instances(self) -> None:
        """Test case for get_action_instances

        Get the details of automation action run results from action run history.
        """
        pass


if __name__ == '__main__':
    unittest.main()
