# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.slo_report import SloReport

class TestSloReport(unittest.TestCase):
    """SloReport unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SloReport:
        """Test SloReport
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SloReport`
        """
        model = SloReport()
        if include_optional:
            return SloReport(
                error_accumulation_chart = {
                    'key' : 56
                    },
                error_budget_remain_chart = {
                    'key' : 56
                    },
                error_budget_remaining = 56,
                error_budget_spent = 56,
                error_burn_rate = 56,
                error_burn_rate_chart = {
                    'key' : 56
                    },
                error_chart = {
                    'key' : 56
                    },
                from_timestamp = 56,
                sli = 1.337,
                slo = 1.337,
                to_timestamp = 56,
                total_error_budget = 56,
                violation_distribution = {
                    'key' : 56
                    }
            )
        else:
            return SloReport(
        )
        """

    def testSloReport(self):
        """Test SloReport"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
