# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.service_levels_objective_slo_configurations_api import ServiceLevelsObjectiveSLOConfigurationsApi


class TestServiceLevelsObjectiveSLOConfigurationsApi(unittest.TestCase):
    """ServiceLevelsObjectiveSLOConfigurationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ServiceLevelsObjectiveSLOConfigurationsApi()

    def tearDown(self) -> None:
        pass

    def test_create_slo_config(self) -> None:
        """Test case for create_slo_config

        Create a new SLO Config
        """
        pass

    def test_delete_slo_config(self) -> None:
        """Test case for delete_slo_config

        Delete an existing SLO Config
        """
        pass

    def test_get_all_slo_config_tags(self) -> None:
        """Test case for get_all_slo_config_tags

        Get All SLO Config tags
        """
        pass

    def test_get_all_slo_configs(self) -> None:
        """Test case for get_all_slo_configs

        Get All SLO Configs
        """
        pass

    def test_get_slo_config_by_id(self) -> None:
        """Test case for get_slo_config_by_id

        Get an existing SLO Config
        """
        pass

    def test_update_slo_config(self) -> None:
        """Test case for update_slo_config

        Update an existing SLO Config
        """
        pass


if __name__ == '__main__':
    unittest.main()
