# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.built_in_event_specification import BuiltInEventSpecification

class TestBuiltInEventSpecification(unittest.TestCase):
    """BuiltInEventSpecification unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BuiltInEventSpecification:
        """Test BuiltInEventSpecification
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BuiltInEventSpecification`
        """
        model = BuiltInEventSpecification()
        if include_optional:
            return BuiltInEventSpecification(
                description = '',
                enabled = True,
                hidden = True,
                hyper_params = [
                    instana_client.models.hyper_param.HyperParam(
                        default_value = 1.337, 
                        description = '', 
                        id = '', 
                        max_value = 1.337, 
                        min_value = 1.337, 
                        name = '', 
                        value_format = 'NUMBER', )
                    ],
                id = '',
                name = '',
                rule_inputs = [
                    instana_client.models.rule_input.RuleInput(
                        input_kind = 'METRIC', 
                        input_name = '', )
                    ],
                severity = 56,
                short_plugin_id = '',
                triggering = True
            )
        else:
            return BuiltInEventSpecification(
                hyper_params = [
                    instana_client.models.hyper_param.HyperParam(
                        default_value = 1.337, 
                        description = '', 
                        id = '', 
                        max_value = 1.337, 
                        min_value = 1.337, 
                        name = '', 
                        value_format = 'NUMBER', )
                    ],
                id = '',
                name = '',
                rule_inputs = [
                    instana_client.models.rule_input.RuleInput(
                        input_kind = 'METRIC', 
                        input_name = '', )
                    ],
                short_plugin_id = '',
        )
        """

    def testBuiltInEventSpecification(self):
        """Test BuiltInEventSpecification"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
