# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.get_test_summary_result import GetTestSummaryResult

class TestGetTestSummaryResult(unittest.TestCase):
    """GetTestSummaryResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetTestSummaryResult:
        """Test GetTestSummaryResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetTestSummaryResult`
        """
        model = GetTestSummaryResult()
        if include_optional:
            return GetTestSummaryResult(
                metrics = [
                    instana_client.models.synthetic_metric_configuration.SyntheticMetricConfiguration(
                        aggregation = 'SUM', 
                        granularity = 56, 
                        metric = '', )
                    ],
                order = instana_client.models.order.Order(
                    by = '', 
                    collation = '', 
                    direction = 'ASC', ),
                pagination = instana_client.models.pagination.Pagination(
                    page = 1, 
                    page_size = 1, ),
                tag_filter_expression = instana_client.models.tag_filter_expression_element.TagFilterExpressionElement(
                    type = '', ),
                tag_filters = [
                    instana_client.models.tag_filter.TagFilter()
                    ],
                time_frame = instana_client.models.time_frame.TimeFrame(
                    to = 56, 
                    window_size = 0, )
            )
        else:
            return GetTestSummaryResult(
                metrics = [
                    instana_client.models.synthetic_metric_configuration.SyntheticMetricConfiguration(
                        aggregation = 'SUM', 
                        granularity = 56, 
                        metric = '', )
                    ],
        )
        """

    def testGetTestSummaryResult(self):
        """Test GetTestSummaryResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
