# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.custom_entities_api import CustomEntitiesApi


class TestCustomEntitiesApi(unittest.TestCase):
    """CustomEntitiesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CustomEntitiesApi()

    def tearDown(self) -> None:
        pass

    def test_create_custom_entities(self) -> None:
        """Test case for create_custom_entities

        Create a Custom Entity type
        """
        pass

    def test_delete_custom_entity(self) -> None:
        """Test case for delete_custom_entity

        Delete a Custom Entity Type
        """
        pass

    def test_get_custom_entity(self) -> None:
        """Test case for get_custom_entity

        Get custom Entity Types
        """
        pass

    def test_list_custom_entities(self) -> None:
        """Test case for list_custom_entities

        List custom Entity Type Definition
        """
        pass

    def test_list_entities_from_infra_entities(self) -> None:
        """Test case for list_entities_from_infra_entities

        List all entity types that match the custom entity metadata
        """
        pass

    def test_update_custom_entity(self) -> None:
        """Test case for update_custom_entity

        Update a Custom Entity Type
        """
        pass


if __name__ == '__main__':
    unittest.main()
