# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.sli_settings_api import SLISettingsApi


class TestSLISettingsApi(unittest.TestCase):
    """SLISettingsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SLISettingsApi()

    def tearDown(self) -> None:
        pass

    def test_create_sli_config(self) -> None:
        """Test case for create_sli_config

        Create SLI Config
        """
        pass

    def test_create_sli_config_v2(self) -> None:
        """Test case for create_sli_config_v2

        Create SLI Config
        """
        pass

    def test_delete_sli_config(self) -> None:
        """Test case for delete_sli_config

        Delete SLI Config
        """
        pass

    def test_delete_sli_config_v2(self) -> None:
        """Test case for delete_sli_config_v2

        Delete SLI Config
        """
        pass

    def test_get_all_sli_configs(self) -> None:
        """Test case for get_all_sli_configs

        Get All SLI Configs
        """
        pass

    def test_get_all_sli_configs_v2(self) -> None:
        """Test case for get_all_sli_configs_v2

        Get All SLI Configs
        """
        pass

    def test_get_sli_config(self) -> None:
        """Test case for get_sli_config

        Get SLI Config
        """
        pass

    def test_get_sli_config_v2(self) -> None:
        """Test case for get_sli_config_v2

        Get SLI Config
        """
        pass

    def test_get_sli_configs_for_entity_type_and_id_v2(self) -> None:
        """Test case for get_sli_configs_for_entity_type_and_id_v2

        Get all SLI configs for entity type and entity id
        """
        pass

    def test_update_sli_config(self) -> None:
        """Test case for update_sli_config

        Update SLI Config
        """
        pass


if __name__ == '__main__':
    unittest.main()
