# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.test_result_detail_data import TestResultDetailData

class TestTestResultDetailData(unittest.TestCase):
    """TestResultDetailData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TestResultDetailData:
        """Test TestResultDetailData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TestResultDetailData`
        """
        model = TestResultDetailData()
        if include_optional:
            return TestResultDetailData(
                har = {
                    'key' : None
                    },
                image_files = {
                    'key' : [
                        'YQ=='
                        ]
                    },
                log_files = {
                    'key' : ''
                    },
                logs = '',
                subtransaction_avg_metrics = {
                    'key' : None
                    },
                subtransactions = [
                    instana_client.models.test_result_subtransaction.TestResultSubtransaction(
                        metrics = {
                            'key' : None
                            }, 
                        properties = {
                            'key' : None
                            }, )
                    ],
                test_id = '',
                test_result_id = '',
                videos = [
                    'YQ=='
                    ]
            )
        else:
            return TestResultDetailData(
        )
        """

    def testTestResultDetailData(self):
        """Test TestResultDetailData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
