# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.get_website_metrics import GetWebsiteMetrics

class TestGetWebsiteMetrics(unittest.TestCase):
    """GetWebsiteMetrics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetWebsiteMetrics:
        """Test GetWebsiteMetrics
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetWebsiteMetrics`
        """
        model = GetWebsiteMetrics()
        if include_optional:
            return GetWebsiteMetrics(
                metrics = [
                    instana_client.models.website_monitoring_metrics_configuration.WebsiteMonitoringMetricsConfiguration(
                        aggregation = 'SUM', 
                        granularity = 56, 
                        metric = '', )
                    ],
                tag_filters = [
                    instana_client.models.deprecated_tag_filter.DeprecatedTagFilter(
                        entity = 'NOT_APPLICABLE', 
                        name = '', 
                        operator = 'EQUALS', 
                        value = '', )
                    ],
                time_frame = instana_client.models.time_frame.TimeFrame(
                    to = 56, 
                    window_size = 0, ),
                type = 'PAGELOAD'
            )
        else:
            return GetWebsiteMetrics(
                metrics = [
                    instana_client.models.website_monitoring_metrics_configuration.WebsiteMonitoringMetricsConfiguration(
                        aggregation = 'SUM', 
                        granularity = 56, 
                        metric = '', )
                    ],
                type = 'PAGELOAD',
        )
        """

    def testGetWebsiteMetrics(self):
        """Test GetWebsiteMetrics"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
