# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.event_filtering_configuration import EventFilteringConfiguration

class TestEventFilteringConfiguration(unittest.TestCase):
    """EventFilteringConfiguration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> EventFilteringConfiguration:
        """Test EventFilteringConfiguration
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EventFilteringConfiguration`
        """
        model = EventFilteringConfiguration()
        if include_optional:
            return EventFilteringConfiguration(
                application_alert_config_ids = [
                    ''
                    ],
                event_types = [
                    'incident'
                    ],
                query = '',
                rule_ids = [
                    ''
                    ]
            )
        else:
            return EventFilteringConfiguration(
        )
        """

    def testEventFilteringConfiguration(self):
        """Test EventFilteringConfiguration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
