# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.custom_dashboards_api import CustomDashboardsApi


class TestCustomDashboardsApi(unittest.TestCase):
    """CustomDashboardsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CustomDashboardsApi()

    def tearDown(self) -> None:
        pass

    def test_add_custom_dashboard(self) -> None:
        """Test case for add_custom_dashboard

        Add custom dashboard
        """
        pass

    def test_delete_custom_dashboard(self) -> None:
        """Test case for delete_custom_dashboard

        Remove custom dashboard
        """
        pass

    def test_get_custom_dashboard(self) -> None:
        """Test case for get_custom_dashboard

        Get custom dashboard
        """
        pass

    def test_get_custom_dashboards(self) -> None:
        """Test case for get_custom_dashboards

        Get accessible custom dashboards
        """
        pass

    def test_get_shareable_api_tokens(self) -> None:
        """Test case for get_shareable_api_tokens

        Get all API tokens.
        """
        pass

    def test_get_shareable_users(self) -> None:
        """Test case for get_shareable_users

        Get all users (without invitations).
        """
        pass

    def test_update_custom_dashboard(self) -> None:
        """Test case for update_custom_dashboard

        Update custom dashboard
        """
        pass


if __name__ == '__main__':
    unittest.main()
