# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.application_settings_api import ApplicationSettingsApi


class TestApplicationSettingsApi(unittest.TestCase):
    """ApplicationSettingsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationSettingsApi()

    def tearDown(self) -> None:
        pass

    def test_add_application_config(self) -> None:
        """Test case for add_application_config

        Add application configuration
        """
        pass

    def test_add_manual_service_config(self) -> None:
        """Test case for add_manual_service_config

        Add manual service configuration
        """
        pass

    def test_add_service_config(self) -> None:
        """Test case for add_service_config

        Add service configuration
        """
        pass

    def test_create_endpoint_config(self) -> None:
        """Test case for create_endpoint_config

        Create endpoint configuration
        """
        pass

    def test_create_http_endpoint_config(self) -> None:
        """Test case for create_http_endpoint_config

        Create HTTP endpoint configuration
        """
        pass

    def test_delete_application_config(self) -> None:
        """Test case for delete_application_config

        Delete application configuration
        """
        pass

    def test_delete_endpoint_config(self) -> None:
        """Test case for delete_endpoint_config

        Delete endpoint configuration
        """
        pass

    def test_delete_http_endpoint_config(self) -> None:
        """Test case for delete_http_endpoint_config

        Delete HTTP endpoint configuration
        """
        pass

    def test_delete_manual_service_config(self) -> None:
        """Test case for delete_manual_service_config

        Delete manual service configuration
        """
        pass

    def test_delete_service_config(self) -> None:
        """Test case for delete_service_config

        Delete service configuration
        """
        pass

    def test_get_all_manual_service_configs(self) -> None:
        """Test case for get_all_manual_service_configs

        All manual service configurations
        """
        pass

    def test_get_application_config(self) -> None:
        """Test case for get_application_config

        Application configuration
        """
        pass

    def test_get_application_configs(self) -> None:
        """Test case for get_application_configs

        All Application configurations
        """
        pass

    def test_get_endpoint_config(self) -> None:
        """Test case for get_endpoint_config

        Endpoint configuration
        """
        pass

    def test_get_endpoint_configs(self) -> None:
        """Test case for get_endpoint_configs

        All Endpoint configurations
        """
        pass

    def test_get_http_endpoint_config(self) -> None:
        """Test case for get_http_endpoint_config

        HTTP Endpoint configuration
        """
        pass

    def test_get_http_endpoint_configs(self) -> None:
        """Test case for get_http_endpoint_configs

        All HTTP endpoint configurations
        """
        pass

    def test_get_service_config(self) -> None:
        """Test case for get_service_config

        Service configuration
        """
        pass

    def test_get_service_configs(self) -> None:
        """Test case for get_service_configs

        All service configurations
        """
        pass

    def test_order_service_config(self) -> None:
        """Test case for order_service_config

        Order of service configuration
        """
        pass

    def test_put_application_config(self) -> None:
        """Test case for put_application_config

        Update application configuration
        """
        pass

    def test_put_service_config(self) -> None:
        """Test case for put_service_config

        Update service configuration
        """
        pass

    def test_replace_all(self) -> None:
        """Test case for replace_all

        Replace all service configurations
        """
        pass

    def test_replace_all_manual_service_configs(self) -> None:
        """Test case for replace_all_manual_service_configs

        Replace all manual service configurations
        """
        pass

    def test_update_endpoint_config(self) -> None:
        """Test case for update_endpoint_config

        Update endpoint configuration
        """
        pass

    def test_update_http_endpoint_config(self) -> None:
        """Test case for update_http_endpoint_config

        Update HTTP endpoint configuration
        """
        pass

    def test_update_manual_service_config(self) -> None:
        """Test case for update_manual_service_config

        Update manual service configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()
