# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.application_metric_result import ApplicationMetricResult

class TestApplicationMetricResult(unittest.TestCase):
    """ApplicationMetricResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApplicationMetricResult:
        """Test ApplicationMetricResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApplicationMetricResult`
        """
        model = ApplicationMetricResult()
        if include_optional:
            return ApplicationMetricResult(
                adjusted_timeframe = instana_client.models.adjusted_timeframe.AdjustedTimeframe(
                    to = 56, 
                    window_size = 0, ),
                items = [
                    instana_client.models.application_item.ApplicationItem(
                        application = instana_client.models.application.Application(
                            boundary_scope = '', 
                            entity_type = 'APPLICATION', 
                            id = '', 
                            label = '', ), 
                        metrics = {
                            'key' : [
                                [
                                    1.337
                                    ]
                                ]
                            }, )
                    ],
                page = 1,
                page_size = 1,
                total_hits = 0
            )
        else:
            return ApplicationMetricResult(
                items = [
                    instana_client.models.application_item.ApplicationItem(
                        application = instana_client.models.application.Application(
                            boundary_scope = '', 
                            entity_type = 'APPLICATION', 
                            id = '', 
                            label = '', ), 
                        metrics = {
                            'key' : [
                                [
                                    1.337
                                    ]
                                ]
                            }, )
                    ],
        )
        """

    def testApplicationMetricResult(self):
        """Test ApplicationMetricResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
