# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.synthetic_alert_configuration_api import SyntheticAlertConfigurationApi


class TestSyntheticAlertConfigurationApi(unittest.TestCase):
    """SyntheticAlertConfigurationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SyntheticAlertConfigurationApi()

    def tearDown(self) -> None:
        pass

    def test_create_synthetic_alert_config(self) -> None:
        """Test case for create_synthetic_alert_config

        Create Synthetic Smart Alert Config
        """
        pass

    def test_delete_synthetic_alert_config(self) -> None:
        """Test case for delete_synthetic_alert_config

        Delete Synthetic Smart Alert Config
        """
        pass

    def test_disable_synthetic_alert_config(self) -> None:
        """Test case for disable_synthetic_alert_config

        Disable Synthetic Smart Alert Config
        """
        pass

    def test_enable_synthetic_alert_config(self) -> None:
        """Test case for enable_synthetic_alert_config

        Enable Synthetic Smart Alert Config
        """
        pass

    def test_find_active_synthetic_alert_configs(self) -> None:
        """Test case for find_active_synthetic_alert_configs

        Get all Synthetic Smart Alert Configs
        """
        pass

    def test_find_synthetic_alert_config(self) -> None:
        """Test case for find_synthetic_alert_config

        Get Synthetic Smart Alert Config
        """
        pass

    def test_find_synthetic_alert_config_versions(self) -> None:
        """Test case for find_synthetic_alert_config_versions

        Get Synthetic Smart Alert Config Versions
        """
        pass

    def test_restore_synthetic_alert_config(self) -> None:
        """Test case for restore_synthetic_alert_config

        Restore Synthetic Smart Alert Config
        """
        pass

    def test_update_synthetic_alert_config(self) -> None:
        """Test case for update_synthetic_alert_config

        Update Synthetic Smart Alert Config
        """
        pass


if __name__ == '__main__':
    unittest.main()
