# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.event_settings_api import EventSettingsApi


class TestEventSettingsApi(unittest.TestCase):
    """EventSettingsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EventSettingsApi()

    def tearDown(self) -> None:
        pass

    def test_create_mobile_app_alert_config(self) -> None:
        """Test case for create_mobile_app_alert_config

        Create Mobile Smart Alert Config
        """
        pass

    def test_create_website_alert_config(self) -> None:
        """Test case for create_website_alert_config

        Create Website Smart Alert Config
        """
        pass

    def test_delete_alert(self) -> None:
        """Test case for delete_alert

        Delete Alert Configuration
        """
        pass

    def test_delete_alerting_channel(self) -> None:
        """Test case for delete_alerting_channel

        Delete Alerting Channel
        """
        pass

    def test_delete_built_in_event_specification(self) -> None:
        """Test case for delete_built_in_event_specification

        Delete built-in event specification
        """
        pass

    def test_delete_custom_event_specification(self) -> None:
        """Test case for delete_custom_event_specification

        Delete custom event specification
        """
        pass

    def test_delete_custom_payload_configuration(self) -> None:
        """Test case for delete_custom_payload_configuration

        Delete Custom Payload Configuration
        """
        pass

    def test_delete_mobile_app_alert_config(self) -> None:
        """Test case for delete_mobile_app_alert_config

        Delete Mobile Smart Alert Config
        """
        pass

    def test_delete_website_alert_config(self) -> None:
        """Test case for delete_website_alert_config

        Delete Website Smart Alert Config
        """
        pass

    def test_disable_built_in_event_specification(self) -> None:
        """Test case for disable_built_in_event_specification

        Disable built-in event specification
        """
        pass

    def test_disable_custom_event_specification(self) -> None:
        """Test case for disable_custom_event_specification

        Disable custom event specification
        """
        pass

    def test_disable_mobile_app_alert_config(self) -> None:
        """Test case for disable_mobile_app_alert_config

        Disable Mobile Smart Alert Config
        """
        pass

    def test_disable_website_alert_config(self) -> None:
        """Test case for disable_website_alert_config

        Disable Website Smart Alert Config
        """
        pass

    def test_enable_built_in_event_specification(self) -> None:
        """Test case for enable_built_in_event_specification

        Enable built-in event specification
        """
        pass

    def test_enable_custom_event_specification(self) -> None:
        """Test case for enable_custom_event_specification

        Enable custom event specification
        """
        pass

    def test_enable_mobile_app_alert_config(self) -> None:
        """Test case for enable_mobile_app_alert_config

        Enable Mobile Smart Alert Config
        """
        pass

    def test_enable_website_alert_config(self) -> None:
        """Test case for enable_website_alert_config

        Enable Website Smart Alert Config
        """
        pass

    def test_find_active_mobile_app_alert_configs(self) -> None:
        """Test case for find_active_mobile_app_alert_configs

        Get all Mobile Smart Alert Configs
        """
        pass

    def test_find_active_website_alert_configs(self) -> None:
        """Test case for find_active_website_alert_configs

        Get all Website Smart Alert Configs
        """
        pass

    def test_find_mobile_app_alert_config(self) -> None:
        """Test case for find_mobile_app_alert_config

        Get Mobile Smart Alert Config
        """
        pass

    def test_find_mobile_app_alert_config_versions(self) -> None:
        """Test case for find_mobile_app_alert_config_versions

        Get Mobile Smart Alert Config Versions
        """
        pass

    def test_find_website_alert_config(self) -> None:
        """Test case for find_website_alert_config

        Get Website Smart Alert Config
        """
        pass

    def test_find_website_alert_config_versions(self) -> None:
        """Test case for find_website_alert_config_versions

        Get Website Smart Alert Config Versions. 
        """
        pass

    def test_get_alert(self) -> None:
        """Test case for get_alert

        Get Alert Configuration
        """
        pass

    def test_get_alerting_channel(self) -> None:
        """Test case for get_alerting_channel

        Get Alerting Channel
        """
        pass

    def test_get_alerting_channels(self) -> None:
        """Test case for get_alerting_channels

        Get all Alerting Channels
        """
        pass

    def test_get_alerting_channels_overview(self) -> None:
        """Test case for get_alerting_channels_overview

        Get Overview of Alerting Channels
        """
        pass

    def test_get_alerting_configuration_infos(self) -> None:
        """Test case for get_alerting_configuration_infos

        All alerting configuration info
        """
        pass

    def test_get_alerts(self) -> None:
        """Test case for get_alerts

        Get all Alert Configurations
        """
        pass

    def test_get_built_in_event_specification(self) -> None:
        """Test case for get_built_in_event_specification

        Built-in event specifications
        """
        pass

    def test_get_built_in_event_specifications(self) -> None:
        """Test case for get_built_in_event_specifications

        All built-in event specification
        """
        pass

    def test_get_custom_event_specification(self) -> None:
        """Test case for get_custom_event_specification

        Custom event specification
        """
        pass

    def test_get_custom_event_specifications(self) -> None:
        """Test case for get_custom_event_specifications

        All custom event specifications
        """
        pass

    def test_get_custom_payload_configurations(self) -> None:
        """Test case for get_custom_payload_configurations

        Get All Global Custom Payload Configurations
        """
        pass

    def test_get_custom_payload_tag_catalog(self) -> None:
        """Test case for get_custom_payload_tag_catalog

        Get Tag Catalog for Custom Payload
        """
        pass

    def test_get_event_specification_infos(self) -> None:
        """Test case for get_event_specification_infos

        Summary of all built-in and custom event specifications
        """
        pass

    def test_get_event_specification_infos_by_ids(self) -> None:
        """Test case for get_event_specification_infos_by_ids

        All built-in and custom event specifications
        """
        pass

    def test_get_system_rules(self) -> None:
        """Test case for get_system_rules

        All system rules for custom event specifications
        """
        pass

    def test_manually_close_event(self) -> None:
        """Test case for manually_close_event

        Manually close an event.
        """
        pass

    def test_multi_close_event(self) -> None:
        """Test case for multi_close_event

        Manually closing multiple events
        """
        pass

    def test_post_alerting_channel(self) -> None:
        """Test case for post_alerting_channel

        Create Alert Channel
        """
        pass

    def test_post_custom_event_specification(self) -> None:
        """Test case for post_custom_event_specification

        Create new custom event specification
        """
        pass

    def test_put_alert(self) -> None:
        """Test case for put_alert

        Create or update Alert Configuration
        """
        pass

    def test_put_alerting_channel(self) -> None:
        """Test case for put_alerting_channel

        Update Alert Channel
        """
        pass

    def test_put_custom_event_specification(self) -> None:
        """Test case for put_custom_event_specification

        Create or update custom event specification
        """
        pass

    def test_restore_mobile_app_alert_config(self) -> None:
        """Test case for restore_mobile_app_alert_config

        Restore Mobile Smart Alert Config
        """
        pass

    def test_restore_website_alert_config(self) -> None:
        """Test case for restore_website_alert_config

        Restore Website Smart Alert Config
        """
        pass

    def test_send_test_alerting(self) -> None:
        """Test case for send_test_alerting

        Test Alerting Channel
        """
        pass

    def test_send_test_alerting_by_id(self) -> None:
        """Test case for send_test_alerting_by_id

        Notify manually to Alerting Channel. Requires the permission called CanConfigureIntegrations.
        """
        pass

    def test_update_mobile_app_alert_config(self) -> None:
        """Test case for update_mobile_app_alert_config

        Update Mobile Smart Alert Config
        """
        pass

    def test_update_mobile_app_historic_baseline(self) -> None:
        """Test case for update_mobile_app_historic_baseline

        Recalculate Mobile Smart Alert Config Baseline
        """
        pass

    def test_update_website_alert_config(self) -> None:
        """Test case for update_website_alert_config

        Update Website Smart Alert Config
        """
        pass

    def test_update_website_historic_baseline(self) -> None:
        """Test case for update_website_historic_baseline

        Recalculate Website Smart Alert Config Baseline
        """
        pass

    def test_upsert_custom_payload_configuration(self) -> None:
        """Test case for upsert_custom_payload_configuration

        Create/Update Global Custom Payload Configuration
        """
        pass

    def test_upsert_custom_payload_configuration_v2(self) -> None:
        """Test case for upsert_custom_payload_configuration_v2

        Create/Update Global Custom Payload Configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()
