# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.synthetic_location import SyntheticLocation

class TestSyntheticLocation(unittest.TestCase):
    """SyntheticLocation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyntheticLocation:
        """Test SyntheticLocation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyntheticLocation`
        """
        model = SyntheticLocation()
        if include_optional:
            return SyntheticLocation(
                configuration = instana_client.models.synthetic_location_configuration.SyntheticLocationConfiguration(
                    cluster_name = '', 
                    namespace = '', 
                    tenant_type = 'Multi', ),
                created_at = 56,
                custom_properties = {
                    'key' : ''
                    },
                description = '',
                display_label = '0',
                geo_point = instana_client.models.synthetic_geo_point.SyntheticGeoPoint(
                    city_name = '', 
                    country_name = '', 
                    latitude = 1.337, 
                    longitude = 1.337, ),
                id = '',
                label = '0',
                location_type = '',
                modified_at = 56,
                observed_at = 56,
                playback_capabilities = instana_client.models.synthetic_playback_capabilities.SyntheticPlaybackCapabilities(
                    browser_type = [
                        'chrome'
                        ], 
                    execution_type = [
                        'CI/CD'
                        ], 
                    synthetic_type = [
                        ''
                        ], ),
                pop_version = '0',
                status = '',
                total_tests = 56
            )
        else:
            return SyntheticLocation(
                geo_point = instana_client.models.synthetic_geo_point.SyntheticGeoPoint(
                    city_name = '', 
                    country_name = '', 
                    latitude = 1.337, 
                    longitude = 1.337, ),
                label = '0',
                location_type = '',
                playback_capabilities = instana_client.models.synthetic_playback_capabilities.SyntheticPlaybackCapabilities(
                    browser_type = [
                        'chrome'
                        ], 
                    execution_type = [
                        'CI/CD'
                        ], 
                    synthetic_type = [
                        ''
                        ], ),
        )
        """

    def testSyntheticLocation(self):
        """Test SyntheticLocation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
