# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.website_analyze_api import WebsiteAnalyzeApi


class TestWebsiteAnalyzeApi(unittest.TestCase):
    """WebsiteAnalyzeApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WebsiteAnalyzeApi()

    def tearDown(self) -> None:
        pass

    def test_get_beacon_groups(self) -> None:
        """Test case for get_beacon_groups

        Get grouped beacon metrics
        """
        pass

    def test_get_beacons(self) -> None:
        """Test case for get_beacons

        Get all beacons
        """
        pass


if __name__ == '__main__':
    unittest.main()
