# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.synthetic_metrics_api import SyntheticMetricsApi


class TestSyntheticMetricsApi(unittest.TestCase):
    """SyntheticMetricsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SyntheticMetricsApi()

    def tearDown(self) -> None:
        pass

    def test_get_metrics_result(self) -> None:
        """Test case for get_metrics_result

        Get Synthetic Metrics
        """
        pass


if __name__ == '__main__':
    unittest.main()
