# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.log_volume_group import LogVolumeGroup

class TestLogVolumeGroup(unittest.TestCase):
    """LogVolumeGroup unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LogVolumeGroup:
        """Test LogVolumeGroup
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LogVolumeGroup`
        """
        model = LogVolumeGroup()
        if include_optional:
            return LogVolumeGroup(
                label = '',
                log_volume = 56
            )
        else:
            return LogVolumeGroup(
                label = '',
                log_volume = 56,
        )
        """

    def testLogVolumeGroup(self):
        """Test LogVolumeGroup"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
