# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.span_excerpt import SpanExcerpt

class TestSpanExcerpt(unittest.TestCase):
    """SpanExcerpt unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SpanExcerpt:
        """Test SpanExcerpt
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SpanExcerpt`
        """
        model = SpanExcerpt()
        if include_optional:
            return SpanExcerpt(
                data = {
                    'key' : None
                    },
                database_integrations = [
                    instana_client.models.database_integration.DatabaseIntegration(
                        type = '', 
                        url = '', )
                    ],
                duration = 0,
                error_count = 0,
                foreign_parent_id = '',
                id = '',
                kind = 'UNKNOWN',
                name = '',
                parent_id = '',
                stack_trace = [
                    instana_client.models.stack_trace_item.StackTraceItem(
                        file = '', 
                        line = '', 
                        method = '', )
                    ],
                start = 1
            )
        else:
            return SpanExcerpt(
                data = {
                    'key' : None
                    },
                id = '',
                kind = 'UNKNOWN',
                name = '',
                stack_trace = [
                    instana_client.models.stack_trace_item.StackTraceItem(
                        file = '', 
                        line = '', 
                        method = '', )
                    ],
        )
        """

    def testSpanExcerpt(self):
        """Test SpanExcerpt"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
