# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.custom_dashboard_with_user_specific_information import CustomDashboardWithUserSpecificInformation

class TestCustomDashboardWithUserSpecificInformation(unittest.TestCase):
    """CustomDashboardWithUserSpecificInformation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CustomDashboardWithUserSpecificInformation:
        """Test CustomDashboardWithUserSpecificInformation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CustomDashboardWithUserSpecificInformation`
        """
        model = CustomDashboardWithUserSpecificInformation()
        if include_optional:
            return CustomDashboardWithUserSpecificInformation(
                access_rules = [
                    instana_client.models.access_rule.AccessRule(
                        access_type = 'READ', 
                        related_id = '', 
                        relation_type = 'USER', )
                    ],
                id = '',
                owner_id = '',
                title = '',
                widgets = [
                    instana_client.models.widget.Widget(
                        config = instana_client.models.config.config(), 
                        height = 1, 
                        id = '', 
                        title = '', 
                        type = '', 
                        width = 1, 
                        x = 0, 
                        y = 0, )
                    ],
                writable = True
            )
        else:
            return CustomDashboardWithUserSpecificInformation(
                access_rules = [
                    instana_client.models.access_rule.AccessRule(
                        access_type = 'READ', 
                        related_id = '', 
                        relation_type = 'USER', )
                    ],
                id = '',
                owner_id = '',
                title = '',
                widgets = [
                    instana_client.models.widget.Widget(
                        config = instana_client.models.config.config(), 
                        height = 1, 
                        id = '', 
                        title = '', 
                        type = '', 
                        width = 1, 
                        x = 0, 
                        y = 0, )
                    ],
                writable = True,
        )
        """

    def testCustomDashboardWithUserSpecificInformation(self):
        """Test CustomDashboardWithUserSpecificInformation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
