# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.threshold_rule import ThresholdRule

class TestThresholdRule(unittest.TestCase):
    """ThresholdRule unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ThresholdRule:
        """Test ThresholdRule
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ThresholdRule`
        """
        model = ThresholdRule()
        if include_optional:
            return ThresholdRule(
                aggregation = 'sum',
                condition_operator = '>',
                condition_value = 1.337,
                metric_name = '',
                metric_pattern = instana_client.models.metric_pattern.MetricPattern(
                    operator = 'is', 
                    placeholder = '', 
                    postfix = '', 
                    prefix = '', ),
                rollup = 56,
                window = 56
            )
        else:
            return ThresholdRule(
                condition_operator = '>',
        )
        """

    def testThresholdRule(self):
        """Test ThresholdRule"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
