# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.llm_egress_gateway import LLMEgressGateway

class TestLLMEgressGateway(unittest.TestCase):
    """LLMEgressGateway unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LLMEgressGateway:
        """Test LLMEgressGateway
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LLMEgressGateway`
        """
        model = LLMEgressGateway()
        if include_optional:
            return LLMEgressGateway(
                ai_model = '',
                configurations = None,
                created_at = '',
                description = '',
                enabled = True,
                endpoint_api_key = '',
                endpoint_url = '',
                id = '',
                instana_agents = None,
                metadata = None,
                modified_at = '',
                name = '',
                prompt = '',
                supports = None,
                system = True,
                tenant_unit_id = '',
                watsonx_key = '',
                watsonx_project = '',
                watsonx_url = ''
            )
        else:
            return LLMEgressGateway(
                created_at = '',
                id = '',
                modified_at = '',
                name = '',
                prompt = '',
                supports = None,
                tenant_unit_id = '',
        )
        """

    def testLLMEgressGateway(self):
        """Test LLMEgressGateway"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
