# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.usage_api import UsageApi


class TestUsageApi(unittest.TestCase):
    """UsageApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UsageApi()

    def tearDown(self) -> None:
        pass

    def test_get_all_usage(self) -> None:
        """Test case for get_all_usage

        API usage by customer
        """
        pass

    def test_get_hosts_per_day(self) -> None:
        """Test case for get_hosts_per_day

        Host count day / month / year
        """
        pass

    def test_get_hosts_per_month(self) -> None:
        """Test case for get_hosts_per_month

        Host count month / year
        """
        pass

    def test_get_usage_per_day(self) -> None:
        """Test case for get_usage_per_day

        API usage day / month / year
        """
        pass

    def test_get_usage_per_month(self) -> None:
        """Test case for get_usage_per_month

        API usage month / year
        """
        pass


if __name__ == '__main__':
    unittest.main()
