# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.website_configuration_api import WebsiteConfigurationApi


class TestWebsiteConfigurationApi(unittest.TestCase):
    """WebsiteConfigurationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WebsiteConfigurationApi()

    def tearDown(self) -> None:
        pass

    def test_clear_source_map_upload_configuration(self) -> None:
        """Test case for clear_source_map_upload_configuration

        Clear source map files for sourcemap upload configuration
        """
        pass

    def test_create_website(self) -> None:
        """Test case for create_website

        Configure new website
        """
        pass

    def test_delete_website(self) -> None:
        """Test case for delete_website

        Remove website
        """
        pass

    def test_delete_website_source_map_upload_configuration(self) -> None:
        """Test case for delete_website_source_map_upload_configuration

        Delete sourcemap upload configuration for website
        """
        pass

    def test_get_website(self) -> None:
        """Test case for get_website

        Get configured website
        """
        pass

    def test_get_website_geo_location_configuration(self) -> None:
        """Test case for get_website_geo_location_configuration

        Get geo location configuration for website
        """
        pass

    def test_get_website_geo_mapping_rules(self) -> None:
        """Test case for get_website_geo_mapping_rules

        Get custom geo mapping rules for website
        """
        pass

    def test_get_website_ip_masking_configuration(self) -> None:
        """Test case for get_website_ip_masking_configuration

        Get IP masking configuration for website
        """
        pass

    def test_get_website_source_map_upload_configuration(self) -> None:
        """Test case for get_website_source_map_upload_configuration

        Get sourcemap upload configurations for website
        """
        pass

    def test_get_website_source_map_upload_configurations(self) -> None:
        """Test case for get_website_source_map_upload_configurations

        Get all sourcemap upload configurations for website
        """
        pass

    def test_get_websites(self) -> None:
        """Test case for get_websites

        Get configured websites
        """
        pass

    def test_post_website_source_map_upload_config(self) -> None:
        """Test case for post_website_source_map_upload_config

        Add new sourcemap upload configuration for website
        """
        pass

    def test_rename_website(self) -> None:
        """Test case for rename_website

        Rename website
        """
        pass

    def test_set_website_geo_mapping_rules(self) -> None:
        """Test case for set_website_geo_mapping_rules

        Set custom geo mapping rules for website
        """
        pass

    def test_update_website_geo_location_configuration(self) -> None:
        """Test case for update_website_geo_location_configuration

        Update geo location configuration for website
        """
        pass

    def test_update_website_ip_masking_configuration(self) -> None:
        """Test case for update_website_ip_masking_configuration

        Update IP masking configuration for website
        """
        pass

    def test_update_website_teams(self) -> None:
        """Test case for update_website_teams

        Update teams assigned to the website
        """
        pass

    def test_upload_source_map_file(self) -> None:
        """Test case for upload_source_map_file

        Upload sourcemap file for website
        """
        pass


if __name__ == '__main__':
    unittest.main()
