# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.business_activity import BusinessActivity

class TestBusinessActivity(unittest.TestCase):
    """BusinessActivity unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BusinessActivity:
        """Test BusinessActivity
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BusinessActivity`
        """
        model = BusinessActivity()
        if include_optional:
            return BusinessActivity(
                activity_id = 'ApproveInvoiceTask',
                activity_name = 'Approve Invoice',
                activity_start = 1680559706000,
                activity_type = 'userTask',
                call_id = '',
                endpoint_ids = [
                    ''
                    ],
                process_definition_id = 'invoice:2:aa2bbbcc-bb04-11ee-9d4e-0242ac110002',
                process_definition_name = 'Invoice Approval',
                root_process_instance_id = '486cbb3b-e633-11ee-8707-0242ac110002'
            )
        else:
            return BusinessActivity(
                activity_type = 'userTask',
        )
        """

    def testBusinessActivity(self):
        """Test BusinessActivity"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
