# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.metrics_result import MetricsResult

class TestMetricsResult(unittest.TestCase):
    """MetricsResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MetricsResult:
        """Test MetricsResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MetricsResult`
        """
        model = MetricsResult()
        if include_optional:
            return MetricsResult(
                metrics_result = [
                    instana_client.models.metrics_result_item.MetricsResultItem(
                        custom_tags = {
                            'key' : ''
                            }, 
                        metrics = [
                            {
                                'key' : None
                                }
                            ], 
                        run_type = '', 
                        tests = [
                            instana_client.models.metrics_test_result_item.MetricsTestResultItem(
                                application_id = '', 
                                application_ids = [
                                    ''
                                    ], 
                                location_id = [
                                    ''
                                    ], 
                                mobile_application_ids = [
                                    ''
                                    ], 
                                service_id = '', 
                                test_id = '', 
                                test_name = '', 
                                website_ids = [
                                    ''
                                    ], )
                            ], )
                    ]
            )
        else:
            return MetricsResult(
                metrics_result = [
                    instana_client.models.metrics_result_item.MetricsResultItem(
                        custom_tags = {
                            'key' : ''
                            }, 
                        metrics = [
                            {
                                'key' : None
                                }
                            ], 
                        run_type = '', 
                        tests = [
                            instana_client.models.metrics_test_result_item.MetricsTestResultItem(
                                application_id = '', 
                                application_ids = [
                                    ''
                                    ], 
                                location_id = [
                                    ''
                                    ], 
                                mobile_application_ids = [
                                    ''
                                    ], 
                                service_id = '', 
                                test_id = '', 
                                test_name = '', 
                                website_ids = [
                                    ''
                                    ], )
                            ], )
                    ],
        )
        """

    def testMetricsResult(self):
        """Test MetricsResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
