# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.service_now_enhanced_integration import ServiceNowEnhancedIntegration

class TestServiceNowEnhancedIntegration(unittest.TestCase):
    """ServiceNowEnhancedIntegration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServiceNowEnhancedIntegration:
        """Test ServiceNowEnhancedIntegration
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServiceNowEnhancedIntegration`
        """
        model = ServiceNowEnhancedIntegration()
        if include_optional:
            return ServiceNowEnhancedIntegration(
                auto_close_incidents = True,
                enable_send_instana_notes = True,
                enable_send_service_now_activities = True,
                enable_send_service_now_work_notes = True,
                instana_url = '',
                manually_closed_incidents = True,
                password = '',
                resolution_of_incident = True,
                service_now_url = '',
                snow_status_on_close_event = 56,
                tenant = '',
                unit = '',
                username = ''
            )
        else:
            return ServiceNowEnhancedIntegration(
                password = '',
                service_now_url = '',
                tenant = '',
                unit = '',
                username = '',
        )
        """

    def testServiceNowEnhancedIntegration(self):
        """Test ServiceNowEnhancedIntegration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
