# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from instana_client.models.mobile_app_time_threshold import MobileAppTimeThreshold
from typing import Optional, Set
from typing_extensions import Self

class UserImpactMobileAppTimeThreshold(MobileAppTimeThreshold):
    """
    UserImpactMobileAppTimeThreshold
    """ # noqa: E501
    impact_measurement_method: StrictStr = Field(alias="impactMeasurementMethod")
    user_percentage: Optional[Union[Annotated[float, Field(le=1.0, strict=True, gt=0.0)], Annotated[int, Field(le=1, strict=True, gt=0)]]] = Field(default=None, alias="userPercentage")
    users: Optional[Annotated[int, Field(strict=True, ge=1)]] = None
    __properties: ClassVar[List[str]] = ["timeWindow", "type", "impactMeasurementMethod", "userPercentage", "users"]

    @field_validator('impact_measurement_method')
    def impact_measurement_method_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['AGGREGATED', 'PER_WINDOW']):
            raise ValueError("must be one of enum values ('AGGREGATED', 'PER_WINDOW')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserImpactMobileAppTimeThreshold from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserImpactMobileAppTimeThreshold from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "timeWindow": obj.get("timeWindow"),
            "type": obj.get("type"),
            "impactMeasurementMethod": obj.get("impactMeasurementMethod"),
            "userPercentage": obj.get("userPercentage"),
            "users": obj.get("users")
        })
        return _obj


