# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.access_log_response import AccessLogResponse

class TestAccessLogResponse(unittest.TestCase):
    """AccessLogResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AccessLogResponse:
        """Test AccessLogResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AccessLogResponse`
        """
        model = AccessLogResponse()
        if include_optional:
            return AccessLogResponse(
                entries = [
                    instana_client.models.access_log_entry.AccessLogEntry(
                        action = 'GRANT_TEMP_ACCESS', 
                        email = '', 
                        full_name = '', 
                        message = '', 
                        meta = {
                            'key' : None
                            }, 
                        tenant_id = '', 
                        tenant_unit_id = '', 
                        timestamp = 1118583367265, )
                    ],
                total = 56
            )
        else:
            return AccessLogResponse(
        )
        """

    def testAccessLogResponse(self):
        """Test AccessLogResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
