# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.get_infrastructure_groups_query import GetInfrastructureGroupsQuery

class TestGetInfrastructureGroupsQuery(unittest.TestCase):
    """GetInfrastructureGroupsQuery unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetInfrastructureGroupsQuery:
        """Test GetInfrastructureGroupsQuery
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetInfrastructureGroupsQuery`
        """
        model = GetInfrastructureGroupsQuery()
        if include_optional:
            return GetInfrastructureGroupsQuery(
                group_by = [
                    ''
                    ],
                metrics = [
                    instana_client.models.infra_metric_configuration.InfraMetricConfiguration()
                    ],
                missing_placeholder = '',
                order = instana_client.models.order.Order(
                    by = '', 
                    collation = '', 
                    direction = 'ASC', ),
                pagination = instana_client.models.cursor_pagination_infra_explore_cursor.CursorPaginationInfraExploreCursor(
                    cursor = instana_client.models.cursor.cursor(), 
                    retrieval_size = 56, ),
                tag_filter_expression = instana_client.models.tag_filter_expression_element.TagFilterExpressionElement(
                    type = '', ),
                time_frame = instana_client.models.time_frame.TimeFrame(
                    to = 56, 
                    window_size = 0, ),
                type = ''
            )
        else:
            return GetInfrastructureGroupsQuery(
                group_by = [
                    ''
                    ],
                pagination = instana_client.models.cursor_pagination_infra_explore_cursor.CursorPaginationInfraExploreCursor(
                    cursor = instana_client.models.cursor.cursor(), 
                    retrieval_size = 56, ),
                tag_filter_expression = instana_client.models.tag_filter_expression_element.TagFilterExpressionElement(
                    type = '', ),
                time_frame = instana_client.models.time_frame.TimeFrame(
                    to = 56, 
                    window_size = 0, ),
        )
        """

    def testGetInfrastructureGroupsQuery(self):
        """Test GetInfrastructureGroupsQuery"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
