# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.alerting_configuration_with_last_updated import AlertingConfigurationWithLastUpdated

class TestAlertingConfigurationWithLastUpdated(unittest.TestCase):
    """AlertingConfigurationWithLastUpdated unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AlertingConfigurationWithLastUpdated:
        """Test AlertingConfigurationWithLastUpdated
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AlertingConfigurationWithLastUpdated`
        """
        model = AlertingConfigurationWithLastUpdated()
        if include_optional:
            return AlertingConfigurationWithLastUpdated(
                alert_name = '',
                custom_payload_fields = [
                    instana_client.models.static_string_field.StaticStringField()
                    ],
                event_filtering_configuration = instana_client.models.event_filtering_configuration.EventFilteringConfiguration(
                    application_alert_config_ids = [
                        ''
                        ], 
                    event_types = [
                        'incident'
                        ], 
                    query = '', 
                    rule_ids = [
                        ''
                        ], ),
                id = '',
                include_entity_name_in_legacy_alerts = True,
                integration_ids = [
                    ''
                    ],
                last_updated = 1,
                mute_until = 56
            )
        else:
            return AlertingConfigurationWithLastUpdated(
                alert_name = '',
                custom_payload_fields = [
                    instana_client.models.static_string_field.StaticStringField()
                    ],
                event_filtering_configuration = instana_client.models.event_filtering_configuration.EventFilteringConfiguration(
                    application_alert_config_ids = [
                        ''
                        ], 
                    event_types = [
                        'incident'
                        ], 
                    query = '', 
                    rule_ids = [
                        ''
                        ], ),
                id = '',
                integration_ids = [
                    ''
                    ],
        )
        """

    def testAlertingConfigurationWithLastUpdated(self):
        """Test AlertingConfigurationWithLastUpdated"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
