# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.policies_api import PoliciesApi


class TestPoliciesApi(unittest.TestCase):
    """PoliciesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PoliciesApi()

    def tearDown(self) -> None:
        pass

    def test_add_policies(self) -> None:
        """Test case for add_policies

        Create automation policies.
        """
        pass

    def test_add_policy(self) -> None:
        """Test case for add_policy

        Create an automation policy.
        """
        pass

    def test_delete_policy(self) -> None:
        """Test case for delete_policy

        Deletes an automation policy by identifier.
        """
        pass

    def test_get_policies(self) -> None:
        """Test case for get_policies

        Get all automation policies.
        """
        pass

    def test_get_policy_by_id(self) -> None:
        """Test case for get_policy_by_id

        Get an automation policy by ID.
        """
        pass

    def test_update_policy(self) -> None:
        """Test case for update_policy

        Updates an automation policy by identifier.
        """
        pass


if __name__ == '__main__':
    unittest.main()
