# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.events_api import EventsApi


class TestEventsApi(unittest.TestCase):
    """EventsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EventsApi()

    def tearDown(self) -> None:
        pass

    def test_agent_monitoring_events(self) -> None:
        """Test case for agent_monitoring_events

        Get Agent Monitoring Events
        """
        pass

    def test_get_event(self) -> None:
        """Test case for get_event

        Get Event
        """
        pass

    def test_get_events(self) -> None:
        """Test case for get_events

        Get all Events
        """
        pass

    def test_get_events_by_ids(self) -> None:
        """Test case for get_events_by_ids

        Get Events by IDs
        """
        pass

    def test_kubernetes_info_events(self) -> None:
        """Test case for kubernetes_info_events

        Get Kubernetes Info Events
        """
        pass


if __name__ == '__main__':
    unittest.main()
