# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.synthetic_test_cicd_item import SyntheticTestCICDItem

class TestSyntheticTestCICDItem(unittest.TestCase):
    """SyntheticTestCICDItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyntheticTestCICDItem:
        """Test SyntheticTestCICDItem
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyntheticTestCICDItem`
        """
        model = SyntheticTestCICDItem()
        if include_optional:
            return SyntheticTestCICDItem(
                applications = [
                    ''
                    ],
                completed = True,
                customization = instana_client.models.synthetic_test_cicd_customization.SyntheticTestCICDCustomization(
                    configuration = instana_client.models.synthetic_configuration.SyntheticConfiguration(
                        retries = 0, 
                        retry_interval = 1, 
                        timeout = '', ), 
                    custom_properties = {
                        'key' : ''
                        }, 
                    locations = [
                        ''
                        ], ),
                location_id = '',
                location_label = '',
                mobile_apps = [
                    ''
                    ],
                run_type = '',
                test_id = '',
                test_label = '',
                test_result_id = '',
                test_type = '',
                websites = [
                    ''
                    ]
            )
        else:
            return SyntheticTestCICDItem(
                completed = True,
                customization = instana_client.models.synthetic_test_cicd_customization.SyntheticTestCICDCustomization(
                    configuration = instana_client.models.synthetic_configuration.SyntheticConfiguration(
                        retries = 0, 
                        retry_interval = 1, 
                        timeout = '', ), 
                    custom_properties = {
                        'key' : ''
                        }, 
                    locations = [
                        ''
                        ], ),
                location_id = '',
                location_label = '',
                test_id = '',
                test_label = '',
                test_result_id = '',
                test_type = '',
        )
        """

    def testSyntheticTestCICDItem(self):
        """Test SyntheticTestCICDItem"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
