# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.ai_management_api import AIManagementApi


class TestAIManagementApi(unittest.TestCase):
    """AIManagementApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AIManagementApi()

    def tearDown(self) -> None:
        pass

    def test_add_llm_egress_gateway(self) -> None:
        """Test case for add_llm_egress_gateway

        Create a new LLM gateway
        """
        pass

    def test_delete_llm_egress_gateway(self) -> None:
        """Test case for delete_llm_egress_gateway

        Delete a LLM egress gateway
        """
        pass

    def test_enable_llm_egress_gateway(self) -> None:
        """Test case for enable_llm_egress_gateway

        Set the enabled status of a LLM gateway
        """
        pass

    def test_get_llm_capabilities(self) -> None:
        """Test case for get_llm_capabilities

        Get all LLM capabilities
        """
        pass

    def test_get_llm_egress_gateway_by_id(self) -> None:
        """Test case for get_llm_egress_gateway_by_id

        Get a LLM gateway by ID
        """
        pass

    def test_get_llm_egress_gateways(self) -> None:
        """Test case for get_llm_egress_gateways

        Get all LLM gateways
        """
        pass

    def test_update_llm_egress_gateway(self) -> None:
        """Test case for update_llm_egress_gateway

        Update an existing LLM gateway.
        """
        pass


if __name__ == '__main__':
    unittest.main()
