# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.synthetic_credential import SyntheticCredential

class TestSyntheticCredential(unittest.TestCase):
    """SyntheticCredential unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyntheticCredential:
        """Test SyntheticCredential
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyntheticCredential`
        """
        model = SyntheticCredential()
        if include_optional:
            return SyntheticCredential(
                application_labels = [
                    ''
                    ],
                applications = [
                    ''
                    ],
                created_at = 56,
                created_by = '',
                credential_name = '0',
                credential_value = '',
                mobile_app_labels = [
                    ''
                    ],
                mobile_apps = [
                    ''
                    ],
                modified_at = 56,
                modified_by = '',
                rbac_tags = [
                    instana_client.models.api_tag.ApiTag(
                        display_name = '', 
                        id = '', )
                    ],
                website_labels = [
                    ''
                    ],
                websites = [
                    ''
                    ]
            )
        else:
            return SyntheticCredential(
                credential_name = '0',
                credential_value = '',
        )
        """

    def testSyntheticCredential(self):
        """Test SyntheticCredential"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
