# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.meta_data import MetaData

class TestMetaData(unittest.TestCase):
    """MetaData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MetaData:
        """Test MetaData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MetaData`
        """
        model = MetaData()
        if include_optional:
            return MetaData(
                ai = [
                    {
                        'key' : None
                        }
                    ],
                ai_originated = True,
                built_in = True,
                read_only = True,
                sensor_imported = True
            )
        else:
            return MetaData(
        )
        """

    def testMetaData(self):
        """Test MetaData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
