# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.tag_catalog import TagCatalog

class TestTagCatalog(unittest.TestCase):
    """TagCatalog unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TagCatalog:
        """Test TagCatalog
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TagCatalog`
        """
        model = TagCatalog()
        if include_optional:
            return TagCatalog(
                tag_tree = [
                    instana_client.models.tag_tree_level.TagTreeLevel(
                        children = [
                            instana_client.models.tag_tree_node.TagTreeNode(
                                icon = '', 
                                label = '', )
                            ], 
                        description = '', 
                        icon = '', 
                        label = '', 
                        queryable = True, 
                        score_boost = 56, 
                        type = '', )
                    ],
                tags = [
                    instana_client.models.tag.Tag(
                        aliases = [
                            ''
                            ], 
                        availability = [
                            'INFRASTRUCTURE_METRICS'
                            ], 
                        can_apply_to_destination = True, 
                        can_apply_to_source = True, 
                        description = '', 
                        id_tag = True, 
                        label = '', 
                        name = '', 
                        type = 'BOOLEAN', )
                    ]
            )
        else:
            return TagCatalog(
                tag_tree = [
                    instana_client.models.tag_tree_level.TagTreeLevel(
                        children = [
                            instana_client.models.tag_tree_node.TagTreeNode(
                                icon = '', 
                                label = '', )
                            ], 
                        description = '', 
                        icon = '', 
                        label = '', 
                        queryable = True, 
                        score_boost = 56, 
                        type = '', )
                    ],
                tags = [
                    instana_client.models.tag.Tag(
                        aliases = [
                            ''
                            ], 
                        availability = [
                            'INFRASTRUCTURE_METRICS'
                            ], 
                        can_apply_to_destination = True, 
                        can_apply_to_source = True, 
                        description = '', 
                        id_tag = True, 
                        label = '', 
                        name = '', 
                        type = 'BOOLEAN', )
                    ],
        )
        """

    def testTagCatalog(self):
        """Test TagCatalog"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
