# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.api_token_api import APITokenApi


class TestAPITokenApi(unittest.TestCase):
    """APITokenApi unit test stubs"""

    def setUp(self) -> None:
        self.api = APITokenApi()

    def tearDown(self) -> None:
        pass

    def test_delete_api_token(self) -> None:
        """Test case for delete_api_token

        Delete API token
        """
        pass

    def test_get_api_token(self) -> None:
        """Test case for get_api_token

        Get API token
        """
        pass

    def test_get_api_tokens(self) -> None:
        """Test case for get_api_tokens

        Get all API Tokens
        """
        pass

    def test_post_api_token(self) -> None:
        """Test case for post_api_token

        Create an API token
        """
        pass

    def test_put_api_token(self) -> None:
        """Test case for put_api_token

        Create or update an API token
        """
        pass


if __name__ == '__main__':
    unittest.main()
