# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.slo_correction_configurations_api import SLOCorrectionConfigurationsApi


class TestSLOCorrectionConfigurationsApi(unittest.TestCase):
    """SLOCorrectionConfigurationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SLOCorrectionConfigurationsApi()

    def tearDown(self) -> None:
        pass

    def test_create_slo_correction_window_config(self) -> None:
        """Test case for create_slo_correction_window_config

        Create a new SLO Correction Window Config
        """
        pass

    def test_delete_slo_correction_window_config(self) -> None:
        """Test case for delete_slo_correction_window_config

        Delete an existing SLO Correction Window Configuration
        """
        pass

    def test_get_all_slo_correction_window_configs(self) -> None:
        """Test case for get_all_slo_correction_window_configs

        Get All SLO Correction Window Configs
        """
        pass

    def test_get_slo_correction_window_config_by_id(self) -> None:
        """Test case for get_slo_correction_window_config_by_id

        Get an existing SLO Correction Window Config
        """
        pass

    def test_update_slo_correction_window_config(self) -> None:
        """Test case for update_slo_correction_window_config

        Update an existing SLO Correction Window Config
        """
        pass


if __name__ == '__main__':
    unittest.main()
