# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.physical_context import PhysicalContext

class TestPhysicalContext(unittest.TestCase):
    """PhysicalContext unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PhysicalContext:
        """Test PhysicalContext
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PhysicalContext`
        """
        model = PhysicalContext()
        if include_optional:
            return PhysicalContext(
                cloudfoundry = instana_client.models.cloudfoundry_physical_context.CloudfoundryPhysicalContext(
                    application = instana_client.models.snapshot_preview.SnapshotPreview(
                        data = {
                            'key' : None
                            }, 
                        id = '', 
                        label = '', 
                        plugin = '', 
                        time = 1, ), 
                    cf_instance_index = '', 
                    organization = instana_client.models.snapshot_preview.SnapshotPreview(
                        id = '', 
                        label = '', 
                        plugin = '', 
                        time = 1, ), 
                    space = , ),
                cluster = instana_client.models.snapshot_preview.SnapshotPreview(
                    data = {
                        'key' : None
                        }, 
                    id = '', 
                    label = '', 
                    plugin = '', 
                    time = 1, ),
                container = instana_client.models.snapshot_preview.SnapshotPreview(
                    data = {
                        'key' : None
                        }, 
                    id = '', 
                    label = '', 
                    plugin = '', 
                    time = 1, ),
                host = instana_client.models.snapshot_preview.SnapshotPreview(
                    data = {
                        'key' : None
                        }, 
                    id = '', 
                    label = '', 
                    plugin = '', 
                    time = 1, ),
                kubernetes = instana_client.models.kubernetes_physical_context.KubernetesPhysicalContext(
                    cluster = instana_client.models.snapshot_preview.SnapshotPreview(
                        data = {
                            'key' : None
                            }, 
                        id = '', 
                        label = '', 
                        plugin = '', 
                        time = 1, ), 
                    namespace = instana_client.models.snapshot_preview.SnapshotPreview(
                        id = '', 
                        label = '', 
                        plugin = '', 
                        time = 1, ), 
                    node = , 
                    pod = , ),
                process = instana_client.models.snapshot_preview.SnapshotPreview(
                    data = {
                        'key' : None
                        }, 
                    id = '', 
                    label = '', 
                    plugin = '', 
                    time = 1, )
            )
        else:
            return PhysicalContext(
        )
        """

    def testPhysicalContext(self):
        """Test PhysicalContext"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
