# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.log_alert_configuration_api import LogAlertConfigurationApi


class TestLogAlertConfigurationApi(unittest.TestCase):
    """LogAlertConfigurationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LogAlertConfigurationApi()

    def tearDown(self) -> None:
        pass

    def test_create_log_alert_config(self) -> None:
        """Test case for create_log_alert_config

        Create Log Alert Config
        """
        pass

    def test_delete_log_alert_config(self) -> None:
        """Test case for delete_log_alert_config

        Delete Log Alert Config
        """
        pass

    def test_disable_log_alert_config(self) -> None:
        """Test case for disable_log_alert_config

        Disable Log Alert Config
        """
        pass

    def test_enable_log_alert_config(self) -> None:
        """Test case for enable_log_alert_config

        Enable Log Alert Config
        """
        pass

    def test_find_active_log_alert_configs(self) -> None:
        """Test case for find_active_log_alert_configs

        All Log Alert Configs
        """
        pass

    def test_find_log_alert_config(self) -> None:
        """Test case for find_log_alert_config

        Get Log Alert Config
        """
        pass

    def test_find_log_alert_config_versions(self) -> None:
        """Test case for find_log_alert_config_versions

        Get versions of Log Alert Config
        """
        pass

    def test_restore_log_alert_config(self) -> None:
        """Test case for restore_log_alert_config

        Restore Log Alert Config
        """
        pass

    def test_update_log_alert_config(self) -> None:
        """Test case for update_log_alert_config

        Update Log Alert Config
        """
        pass


if __name__ == '__main__':
    unittest.main()
