# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.infrastructure_catalog_api import InfrastructureCatalogApi


class TestInfrastructureCatalogApi(unittest.TestCase):
    """InfrastructureCatalogApi unit test stubs"""

    def setUp(self) -> None:
        self.api = InfrastructureCatalogApi()

    def tearDown(self) -> None:
        pass

    def test_get_available_payload_keys_by_plugin_id(self) -> None:
        """Test case for get_available_payload_keys_by_plugin_id

        Get payload keys for plugin
        """
        pass

    def test_get_infrastructure_catalog_metrics(self) -> None:
        """Test case for get_infrastructure_catalog_metrics

        Get metric catalog
        """
        pass

    def test_get_infrastructure_catalog_plugins(self) -> None:
        """Test case for get_infrastructure_catalog_plugins

        Get plugin catalog
        """
        pass

    def test_get_infrastructure_catalog_plugins_with_custom_metrics(self) -> None:
        """Test case for get_infrastructure_catalog_plugins_with_custom_metrics

        Get all plugins with custom metrics catalog
        """
        pass

    def test_get_infrastructure_catalog_search_fields(self) -> None:
        """Test case for get_infrastructure_catalog_search_fields

        get search field catalog
        """
        pass

    def test_get_tag_catalog(self) -> None:
        """Test case for get_tag_catalog

        Get available tags for a particular plugin
        """
        pass

    def test_get_tag_catalog_all(self) -> None:
        """Test case for get_tag_catalog_all

        Get available tags
        """
        pass


if __name__ == '__main__':
    unittest.main()
