# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.test_common_properties import TestCommonProperties

class TestTestCommonProperties(unittest.TestCase):
    """TestCommonProperties unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TestCommonProperties:
        """Test TestCommonProperties
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TestCommonProperties`
        """
        model = TestCommonProperties()
        if include_optional:
            return TestCommonProperties(
                active = True,
                application_id = '',
                application_ids = [
                    ''
                    ],
                application_label = '',
                application_labels = [
                    ''
                    ],
                created_at = 56,
                frequency = 56,
                get_website_labels = [
                    ''
                    ],
                id = '',
                label = '',
                location_display_labels = [
                    ''
                    ],
                location_ids = [
                    ''
                    ],
                location_labels = [
                    ''
                    ],
                location_status_list = [
                    instana_client.models.location_status.LocationStatus(
                        location_display_label = '', 
                        location_id = '', 
                        success_rate = 1.337, 
                        success_runs = 56, 
                        total_test_runs = 56, )
                    ],
                mobile_application_ids = [
                    ''
                    ],
                mobile_application_labels = [
                    ''
                    ],
                modified_at = 56,
                service_id = '',
                type = '',
                website_ids = [
                    ''
                    ],
                website_labels = [
                    ''
                    ]
            )
        else:
            return TestCommonProperties(
                active = True,
                frequency = 56,
                id = '',
                label = '',
                type = '',
        )
        """

    def testTestCommonProperties(self):
        """Test TestCommonProperties"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
