# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class Parameter(BaseModel):
    """
    List of inputs to the action.
    """ # noqa: E501
    description: Optional[StrictStr] = Field(default=None, description="Parameter description.")
    hidden: Optional[StrictBool] = Field(default=None, description="Is parameter hidden or not.")
    label: StrictStr = Field(description="Parameter label.")
    name: StrictStr = Field(description="Parameter name.")
    required: Optional[StrictBool] = Field(default=None, description="Is parameter required or not.")
    secured: Optional[StrictBool] = Field(default=None, description="Is parameter secured or not.")
    type: StrictStr = Field(description="Parameter type. Valid values are `static`, `dynamic`, or `vault`. Default value is `static`")
    value: Optional[StrictStr] = Field(default=None, description="Parameter value.")
    __properties: ClassVar[List[str]] = ["description", "hidden", "label", "name", "required", "secured", "type", "value"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Parameter from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Parameter from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "description": obj.get("description"),
            "hidden": obj.get("hidden"),
            "label": obj.get("label"),
            "name": obj.get("name"),
            "required": obj.get("required"),
            "secured": obj.get("secured"),
            "type": obj.get("type"),
            "value": obj.get("value")
        })
        return _obj


