# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.host_agent_api import HostAgentApi


class TestHostAgentApi(unittest.TestCase):
    """HostAgentApi unit test stubs"""

    def setUp(self) -> None:
        self.api = HostAgentApi()

    def tearDown(self) -> None:
        pass

    def test_get_agent_clr_logs(self) -> None:
        """Test case for get_agent_clr_logs

        Agent CLR download logs
        """
        pass

    def test_get_agent_logs(self) -> None:
        """Test case for get_agent_logs

        Agent download logs
        """
        pass

    def test_get_agent_snapshot(self) -> None:
        """Test case for get_agent_snapshot

        Get host agent snapshot details
        """
        pass

    def test_get_agent_support_information(self) -> None:
        """Test case for get_agent_support_information

        Agent download support information
        """
        pass

    def test_search_host_agents(self) -> None:
        """Test case for search_host_agents

        Query host agent snapshots
        """
        pass

    def test_update_agent(self) -> None:
        """Test case for update_agent

        Agent update
        """
        pass

    def test_update_configuration_by_host(self) -> None:
        """Test case for update_configuration_by_host

        Update agent configuration by host
        """
        pass

    def test_update_configuration_by_query(self) -> None:
        """Test case for update_configuration_by_query

        Update agent configuration by query
        """
        pass


if __name__ == '__main__':
    unittest.main()
