# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.service_map import ServiceMap

class TestServiceMap(unittest.TestCase):
    """ServiceMap unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServiceMap:
        """Test ServiceMap
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServiceMap`
        """
        model = ServiceMap()
        if include_optional:
            return ServiceMap(
                connections = [
                    instana_client.models.service_map_connection.ServiceMapConnection(
                        calls = 0, 
                        error_rate = 0, 
                        from = '', 
                        latency = 0, 
                        to = '', )
                    ],
                services = [
                    instana_client.models.extended_service.ExtendedService(
                        applications = [
                            ''
                            ], 
                        entity_type = 'APPLICATION', 
                        id = '', 
                        label = '', 
                        max_severity = 0, 
                        number_of_open_issues = 0, 
                        snapshot_ids = [
                            ''
                            ], 
                        technologies = [
                            ''
                            ], 
                        types = [
                            'UNDEFINED'
                            ], )
                    ]
            )
        else:
            return ServiceMap(
                connections = [
                    instana_client.models.service_map_connection.ServiceMapConnection(
                        calls = 0, 
                        error_rate = 0, 
                        from = '', 
                        latency = 0, 
                        to = '', )
                    ],
                services = [
                    instana_client.models.extended_service.ExtendedService(
                        applications = [
                            ''
                            ], 
                        entity_type = 'APPLICATION', 
                        id = '', 
                        label = '', 
                        max_severity = 0, 
                        number_of_open_issues = 0, 
                        snapshot_ids = [
                            ''
                            ], 
                        technologies = [
                            ''
                            ], 
                        types = [
                            'UNDEFINED'
                            ], )
                    ],
        )
        """

    def testServiceMap(self):
        """Test ServiceMap"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
