# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.global_application_alert_configuration_api import GlobalApplicationAlertConfigurationApi


class TestGlobalApplicationAlertConfigurationApi(unittest.TestCase):
    """GlobalApplicationAlertConfigurationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = GlobalApplicationAlertConfigurationApi()

    def tearDown(self) -> None:
        pass

    def test_create_global_application_alert_config(self) -> None:
        """Test case for create_global_application_alert_config

        Create Global Smart Alert Config
        """
        pass

    def test_delete_global_application_alert_config(self) -> None:
        """Test case for delete_global_application_alert_config

        Delete Global Smart Alert Config
        """
        pass

    def test_disable_global_application_alert_config(self) -> None:
        """Test case for disable_global_application_alert_config

        Disable Global Smart Alert Config
        """
        pass

    def test_enable_global_application_alert_config(self) -> None:
        """Test case for enable_global_application_alert_config

        Enable Global Smart Alert Config
        """
        pass

    def test_find_active_global_application_alert_configs(self) -> None:
        """Test case for find_active_global_application_alert_configs

        Get all Global Smart Alert Configs
        """
        pass

    def test_find_global_application_alert_config(self) -> None:
        """Test case for find_global_application_alert_config

        Get Global Smart Alert Config
        """
        pass

    def test_find_global_application_alert_config_versions(self) -> None:
        """Test case for find_global_application_alert_config_versions

        Get Global Smart Alert Config Versions
        """
        pass

    def test_restore_global_application_alert_config(self) -> None:
        """Test case for restore_global_application_alert_config

        Restore Global Smart Alert Config
        """
        pass

    def test_update_global_application_alert_config(self) -> None:
        """Test case for update_global_application_alert_config

        Update Global Smart Alert Config
        """
        pass


if __name__ == '__main__':
    unittest.main()
