# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.action_catalog_api import ActionCatalogApi


class TestActionCatalogApi(unittest.TestCase):
    """ActionCatalogApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ActionCatalogApi()

    def tearDown(self) -> None:
        pass

    def test_get_action_by_id(self) -> None:
        """Test case for get_action_by_id

        Get an automation action by ID.
        """
        pass

    def test_get_action_matches(self) -> None:
        """Test case for get_action_matches

        Get automation actions that match the incidents or issues.
        """
        pass

    def test_get_action_matches_by_id_and_time_window(self) -> None:
        """Test case for get_action_matches_by_id_and_time_window

        Get action matches by application ID or snapshot ID.
        """
        pass

    def test_get_actions(self) -> None:
        """Test case for get_actions

        Get all automation actions.
        """
        pass

    def test_get_dynamic_parameters_tag_catalog(self) -> None:
        """Test case for get_dynamic_parameters_tag_catalog

        Get tag catalog for dynamic parameters
        """
        pass

    def test_resolve(self) -> None:
        """Test case for resolve

        Resolve dynamic parameter values
        """
        pass


if __name__ == '__main__':
    unittest.main()
