# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.source_map_upload_config import SourceMapUploadConfig

class TestSourceMapUploadConfig(unittest.TestCase):
    """SourceMapUploadConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SourceMapUploadConfig:
        """Test SourceMapUploadConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SourceMapUploadConfig`
        """
        model = SourceMapUploadConfig()
        if include_optional:
            return SourceMapUploadConfig(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                description = '',
                id = '',
                metadata = [
                    instana_client.models.source_map_file_meta.SourceMapFileMeta(
                        blobs = [
                            instana_client.models.source_map_file_blob.SourceMapFileBlob(
                                blob_index = 56, 
                                size = 56, 
                                size_on_disk = 56, )
                            ], 
                        format = '', 
                        meta = '', 
                        size = 56, 
                        size_on_disk = 56, 
                        type = 'JS_MAP', 
                        url = '', )
                    ],
                modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return SourceMapUploadConfig(
                id = '',
                metadata = [
                    instana_client.models.source_map_file_meta.SourceMapFileMeta(
                        blobs = [
                            instana_client.models.source_map_file_blob.SourceMapFileBlob(
                                blob_index = 56, 
                                size = 56, 
                                size_on_disk = 56, )
                            ], 
                        format = '', 
                        meta = '', 
                        size = 56, 
                        size_on_disk = 56, 
                        type = 'JS_MAP', 
                        url = '', )
                    ],
        )
        """

    def testSourceMapUploadConfig(self):
        """Test SourceMapUploadConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
