# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import ConfigDict, Field, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from instana_client.models.abstract_rule import AbstractRule
from instana_client.models.metric_pattern import MetricPattern
from typing import Optional, Set
from typing_extensions import Self

class ThresholdRule(AbstractRule):
    """
    ThresholdRule
    """ # noqa: E501
    aggregation: Optional[StrictStr] = None
    condition_operator: StrictStr = Field(alias="conditionOperator")
    condition_value: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="conditionValue")
    metric_name: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=512)]] = Field(default=None, alias="metricName")
    metric_pattern: Optional[MetricPattern] = Field(default=None, alias="metricPattern")
    rollup: Optional[StrictInt] = None
    window: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["ruleType", "severity", "aggregation", "conditionOperator", "conditionValue", "metricName", "metricPattern", "rollup", "window"]

    @field_validator('aggregation')
    def aggregation_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['sum', 'avg', 'min', 'max', 'absolute_diff', 'relative_diff']):
            raise ValueError("must be one of enum values ('sum', 'avg', 'min', 'max', 'absolute_diff', 'relative_diff')")
        return value

    @field_validator('condition_operator')
    def condition_operator_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['>', '>=', '<', '<=', '=', '!=']):
            raise ValueError("must be one of enum values ('>', '>=', '<', '<=', '=', '!=')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ThresholdRule from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of metric_pattern
        if self.metric_pattern:
            _dict['metricPattern'] = self.metric_pattern.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ThresholdRule from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "ruleType": obj.get("ruleType"),
            "severity": obj.get("severity"),
            "aggregation": obj.get("aggregation"),
            "conditionOperator": obj.get("conditionOperator"),
            "conditionValue": obj.get("conditionValue"),
            "metricName": obj.get("metricName"),
            "metricPattern": MetricPattern.from_dict(obj["metricPattern"]) if obj.get("metricPattern") is not None else None,
            "rollup": obj.get("rollup"),
            "window": obj.get("window")
        })
        return _obj


