# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.users_result import UsersResult

class TestUsersResult(unittest.TestCase):
    """UsersResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UsersResult:
        """Test UsersResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UsersResult`
        """
        model = UsersResult()
        if include_optional:
            return UsersResult(
                invitations = [
                    instana_client.models.invitation_result.InvitationResult(
                        invitation_status = 'SUCCESS', 
                        user_email = '', )
                    ],
                users = [
                    instana_client.models.user_result.UserResult(
                        email = '', 
                        full_name = '', 
                        group_count = 56, 
                        id = '', 
                        last_logged_in = 56, 
                        tfa_enabled = True, )
                    ]
            )
        else:
            return UsersResult(
        )
        """

    def testUsersResult(self):
        """Test UsersResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
