# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.synthetic_test_playback_results_api import SyntheticTestPlaybackResultsApi


class TestSyntheticTestPlaybackResultsApi(unittest.TestCase):
    """SyntheticTestPlaybackResultsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SyntheticTestPlaybackResultsApi()

    def tearDown(self) -> None:
        pass

    def test_get_location_summary_list(self) -> None:
        """Test case for get_location_summary_list

        Get a list of Synthetic locations with last run test on each location data
        """
        pass

    def test_get_synthetic_result(self) -> None:
        """Test case for get_synthetic_result

        Get Synthetic test playback results
        """
        pass

    def test_get_synthetic_result_analytic(self) -> None:
        """Test case for get_synthetic_result_analytic

        Get a list of Synthetic tests based on the specified analytic function
        """
        pass

    def test_get_synthetic_result_detail_data(self) -> None:
        """Test case for get_synthetic_result_detail_data

        Get Synthetic test playback result detail data
        """
        pass

    def test_get_synthetic_result_detail_data_file(self) -> None:
        """Test case for get_synthetic_result_detail_data_file

        Download the synthetic test playback result detail data file
        """
        pass

    def test_get_synthetic_result_list(self) -> None:
        """Test case for get_synthetic_result_list

        Get a list of Synthetic test playback results
        """
        pass

    def test_get_synthetic_result_metadata(self) -> None:
        """Test case for get_synthetic_result_metadata

        Get Synthetic test playback detail result description(metadata)
        """
        pass

    def test_get_test_summary_list(self) -> None:
        """Test case for get_test_summary_list

        Get a list of Synthetic tests with success rate and average response time data
        """
        pass


if __name__ == '__main__':
    unittest.main()
