# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.topology import Topology

class TestTopology(unittest.TestCase):
    """Topology unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Topology:
        """Test Topology
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Topology`
        """
        model = Topology()
        if include_optional:
            return Topology(
                edges = [
                    instana_client.models.graph_edge.GraphEdge(
                        destination = '', 
                        relation = 'in', 
                        source = '', )
                    ],
                nodes = [
                    instana_client.models.graph_node.GraphNode(
                        data = {
                            'key' : None
                            }, 
                        entity_id = instana_client.models.entity_id.EntityId(
                            host = '', 
                            plugin_id = '', 
                            steady_id = '', ), 
                        id = '', 
                        label = '', 
                        plugin = '', )
                    ]
            )
        else:
            return Topology(
        )
        """

    def testTopology(self):
        """Test Topology"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
