# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.geo_location_configuration import GeoLocationConfiguration

class TestGeoLocationConfiguration(unittest.TestCase):
    """GeoLocationConfiguration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GeoLocationConfiguration:
        """Test GeoLocationConfiguration
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GeoLocationConfiguration`
        """
        model = GeoLocationConfiguration()
        if include_optional:
            return GeoLocationConfiguration(
                geo_detail_removal = 'NO_REMOVAL',
                geo_mapping_rules = [
                    instana_client.models.geo_mapping_rule.GeoMappingRule(
                        accuracy_radius = -1, 
                        cidr = '', 
                        city = '', 
                        continent = '', 
                        continent_code = '', 
                        country = '', 
                        country_code = '', 
                        latitude = 1.337, 
                        least_specific_subdivision = instana_client.models.geo_subdivision.GeoSubdivision(
                            code = '', 
                            name = '', ), 
                        longitude = 1.337, 
                        subdivisions = [
                            instana_client.models.geo_subdivision.GeoSubdivision(
                                code = '', 
                                name = '', )
                            ], )
                    ]
            )
        else:
            return GeoLocationConfiguration(
                geo_detail_removal = 'NO_REMOVAL',
        )
        """

    def testGeoLocationConfiguration(self):
        """Test GeoLocationConfiguration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
