# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.available_metrics import AvailableMetrics

class TestAvailableMetrics(unittest.TestCase):
    """AvailableMetrics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AvailableMetrics:
        """Test AvailableMetrics
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AvailableMetrics`
        """
        model = AvailableMetrics()
        if include_optional:
            return AvailableMetrics(
                metrics = [
                    instana_client.models.metric_metadata.MetricMetadata(
                        category = '', 
                        cross_series_aggregations = [
                            'SUM'
                            ], 
                        description = '', 
                        format = 'NUMBER', 
                        id = '', 
                        infra_tag_category = 'ACE', 
                        label = '', 
                        owner_type = '', 
                        tags = [
                            ''
                            ], )
                    ]
            )
        else:
            return AvailableMetrics(
        )
        """

    def testAvailableMetrics(self):
        """Test AvailableMetrics"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
