# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.application_alert_configuration_api import ApplicationAlertConfigurationApi


class TestApplicationAlertConfigurationApi(unittest.TestCase):
    """ApplicationAlertConfigurationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationAlertConfigurationApi()

    def tearDown(self) -> None:
        pass

    def test_create_application_alert_config(self) -> None:
        """Test case for create_application_alert_config

        Create Smart Alert Config
        """
        pass

    def test_delete_application_alert_config(self) -> None:
        """Test case for delete_application_alert_config

        Delete Smart Alert Config
        """
        pass

    def test_disable_application_alert_config(self) -> None:
        """Test case for disable_application_alert_config

        Disable Smart Alert Config
        """
        pass

    def test_enable_application_alert_config(self) -> None:
        """Test case for enable_application_alert_config

        Enable Application Alert Config
        """
        pass

    def test_find_all_active_application_alert_configs(self) -> None:
        """Test case for find_all_active_application_alert_configs

        Get all Smart Alert Configs
        """
        pass

    def test_find_application_alert_config(self) -> None:
        """Test case for find_application_alert_config

        Get Smart Alert Config
        """
        pass

    def test_find_application_alert_config_versions(self) -> None:
        """Test case for find_application_alert_config_versions

        Get Smart Alert Config Versions
        """
        pass

    def test_restore_application_alert_config(self) -> None:
        """Test case for restore_application_alert_config

        Restore Smart Alert Config
        """
        pass

    def test_update_application_alert_config(self) -> None:
        """Test case for update_application_alert_config

        Update Smart Alert Config
        """
        pass

    def test_update_application_historic_baseline(self) -> None:
        """Test case for update_application_historic_baseline

        Recalculate Smart Alert Config Baseline
        """
        pass


if __name__ == '__main__':
    unittest.main()
