# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.synthetic_call_with_defaults_config import SyntheticCallWithDefaultsConfig

class TestSyntheticCallWithDefaultsConfig(unittest.TestCase):
    """SyntheticCallWithDefaultsConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyntheticCallWithDefaultsConfig:
        """Test SyntheticCallWithDefaultsConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyntheticCallWithDefaultsConfig`
        """
        model = SyntheticCallWithDefaultsConfig()
        if include_optional:
            return SyntheticCallWithDefaultsConfig(
                custom_rules = [
                    instana_client.models.synthetic_call_rule.SyntheticCallRule(
                        description = '', 
                        enabled = True, 
                        match_specification = instana_client.models.match_expression_dto.MatchExpressionDTO(
                            type = '', ), 
                        name = '0', )
                    ],
                default_rules = [
                    instana_client.models.synthetic_call_rule.SyntheticCallRule(
                        description = '', 
                        enabled = True, 
                        match_specification = instana_client.models.match_expression_dto.MatchExpressionDTO(
                            type = '', ), 
                        name = '0', )
                    ],
                default_rules_enabled = True
            )
        else:
            return SyntheticCallWithDefaultsConfig(
                custom_rules = [
                    instana_client.models.synthetic_call_rule.SyntheticCallRule(
                        description = '', 
                        enabled = True, 
                        match_specification = instana_client.models.match_expression_dto.MatchExpressionDTO(
                            type = '', ), 
                        name = '0', )
                    ],
                default_rules = [
                    instana_client.models.synthetic_call_rule.SyntheticCallRule(
                        description = '', 
                        enabled = True, 
                        match_specification = instana_client.models.match_expression_dto.MatchExpressionDTO(
                            type = '', ), 
                        name = '0', )
                    ],
        )
        """

    def testSyntheticCallWithDefaultsConfig(self):
        """Test SyntheticCallWithDefaultsConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
