# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.end_user_monitoring_api import EndUserMonitoringApi


class TestEndUserMonitoringApi(unittest.TestCase):
    """EndUserMonitoringApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EndUserMonitoringApi()

    def tearDown(self) -> None:
        pass

    def test_get_impacted_users_report(self) -> None:
        """Test case for get_impacted_users_report

        Get impacted users report
        """
        pass


if __name__ == '__main__':
    unittest.main()
