# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.service_levels_alert_configuration_api import ServiceLevelsAlertConfigurationApi


class TestServiceLevelsAlertConfigurationApi(unittest.TestCase):
    """ServiceLevelsAlertConfigurationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ServiceLevelsAlertConfigurationApi()

    def tearDown(self) -> None:
        pass

    def test_create_service_levels_alert_config(self) -> None:
        """Test case for create_service_levels_alert_config

        Create Service levels Alert Config
        """
        pass

    def test_delete_service_levels_alert_config(self) -> None:
        """Test case for delete_service_levels_alert_config

        Delete Service levels Alert Config
        """
        pass

    def test_disable_service_levels_alert_config(self) -> None:
        """Test case for disable_service_levels_alert_config

        Disable Service levels Alert Config
        """
        pass

    def test_enable_service_levels_alert_config(self) -> None:
        """Test case for enable_service_levels_alert_config

        Enable Service levels Alert Config
        """
        pass

    def test_find_active_service_levels_alert_configs(self) -> None:
        """Test case for find_active_service_levels_alert_configs

        All Service levels Alert Configs
        """
        pass

    def test_find_service_levels_alert_config(self) -> None:
        """Test case for find_service_levels_alert_config

        Get Service levels Alert Config
        """
        pass

    def test_find_service_levels_alert_config_versions(self) -> None:
        """Test case for find_service_levels_alert_config_versions

        Get versions of Service levels Alert Config
        """
        pass

    def test_restore_service_levels_alert_config(self) -> None:
        """Test case for restore_service_levels_alert_config

        Restore Service levels Alert Config
        """
        pass

    def test_update_service_levels_alert_config(self) -> None:
        """Test case for update_service_levels_alert_config

        Update Service levels Alert Config
        """
        pass


if __name__ == '__main__':
    unittest.main()
