# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.user_api import UserApi


class TestUserApi(unittest.TestCase):
    """UserApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UserApi()

    def tearDown(self) -> None:
        pass

    def test_get_invitations(self) -> None:
        """Test case for get_invitations

        All pending invitations
        """
        pass

    def test_get_user_by_id(self) -> None:
        """Test case for get_user_by_id

        Get single user
        """
        pass

    def test_get_users(self) -> None:
        """Test case for get_users

        All users (without invitations)
        """
        pass

    def test_get_users_including_invitations(self) -> None:
        """Test case for get_users_including_invitations

        All users (incl. invitations)
        """
        pass

    def test_invite_users(self) -> None:
        """Test case for invite_users

        Send user invitations
        """
        pass

    def test_remove_user_from_tenant(self) -> None:
        """Test case for remove_user_from_tenant

        Remove user from tenant
        """
        pass

    def test_remove_users_from_tenant(self) -> None:
        """Test case for remove_users_from_tenant

        Remove users from tenant
        """
        pass

    def test_revoke_pending_invitation(self) -> None:
        """Test case for revoke_pending_invitation

        Revoke pending invitation
        """
        pass

    def test_share_and_invite_users(self) -> None:
        """Test case for share_and_invite_users

        Send user invitations
        """
        pass

    def test_update_user(self) -> None:
        """Test case for update_user

        Change user name of single user
        """
        pass


if __name__ == '__main__':
    unittest.main()
